#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .multiphase_options import multiphase_options as multiphase_options_cls
from .turbulence_multiphase_models import turbulence_multiphase_models as turbulence_multiphase_models_cls
from .rsm_multiphase_models import rsm_multiphase_models as rsm_multiphase_models_cls
from .subgrid_turbulence_contribution_aiad import subgrid_turbulence_contribution_aiad as subgrid_turbulence_contribution_aiad_cls

class multiphase_turbulence(Group):
    fluent_name = ...
    child_names = ...
    multiphase_options: multiphase_options_cls = ...
    turbulence_multiphase_models: turbulence_multiphase_models_cls = ...
    rsm_multiphase_models: rsm_multiphase_models_cls = ...
    subgrid_turbulence_contribution_aiad: subgrid_turbulence_contribution_aiad_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .display_1 import display as display_cls
from .copy_3 import copy as copy_cls
from .add_to_graphics import add_to_graphics as add_to_graphics_cls
from .clear_history import clear_history as clear_history_cls
from .vector_child import vector_child


class vector(NamedObject[vector_child], CreatableNamedObjectMixinOld[vector_child]):
    """
    'vector' child.
    """

    fluent_name = "vector"

    command_names = \
        ['display', 'copy', 'add_to_graphics', 'clear_history']

    _child_classes = dict(
        display=display_cls,
        copy=copy_cls,
        add_to_graphics=add_to_graphics_cls,
        clear_history=clear_history_cls,
    )

    child_object_type: vector_child = vector_child
    """
    child_object_type of vector.
    """
    return_type = "<object object at 0x7fc5542439e0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .continuous_phase import continuous_phase as continuous_phase_cls
from .enable_rough_wall_treatment import enable_rough_wall_treatment as enable_rough_wall_treatment_cls
from .volume_displacement import volume_displacement as volume_displacement_cls

class interaction(Group):
    """
    'interaction' child.
    """

    fluent_name = "interaction"

    child_names = \
        ['continuous_phase', 'enable_rough_wall_treatment',
         'volume_displacement']

    _child_classes = dict(
        continuous_phase=continuous_phase_cls,
        enable_rough_wall_treatment=enable_rough_wall_treatment_cls,
        volume_displacement=volume_displacement_cls,
    )

    return_type = "<object object at 0x7fc5c18a7260>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .enable_5 import enable as enable_cls
from .time_delay import time_delay as time_delay_cls

class particle_reinjector(Group):
    """
    'particle_reinjector' child.
    """

    fluent_name = "particle-reinjector"

    child_names = \
        ['enable', 'time_delay']

    _child_classes = dict(
        enable=enable_cls,
        time_delay=time_delay_cls,
    )

    return_type = "<object object at 0x7fb66c2e0770>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .setup_reduction import setup_reduction as setup_reduction_cls
from .pick_sample_to_reduce import pick_sample_to_reduce as pick_sample_to_reduce_cls
from .reduce_picked_sample import reduce_picked_sample as reduce_picked_sample_cls

class reduction(Group):
    """
    'reduction' child.
    """

    fluent_name = "reduction"

    child_names = \
        ['setup_reduction']

    command_names = \
        ['pick_sample_to_reduce', 'reduce_picked_sample']

    _child_classes = dict(
        setup_reduction=setup_reduction_cls,
        pick_sample_to_reduce=pick_sample_to_reduce_cls,
        reduce_picked_sample=reduce_picked_sample_cls,
    )

    return_type = "<object object at 0x7fc55413fcf0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .flow_cp_interpolation_enabled import flow_cp_interpolation_enabled as flow_cp_interpolation_enabled_cls
from .flow_density_interpolation_enabled import flow_density_interpolation_enabled as flow_density_interpolation_enabled_cls
from .flow_gradient_interpolation_enabled import flow_gradient_interpolation_enabled as flow_gradient_interpolation_enabled_cls
from .flow_viscosity_interpolation_enabled import flow_viscosity_interpolation_enabled as flow_viscosity_interpolation_enabled_cls
from .flow_temperature_interpolation_enabled import flow_temperature_interpolation_enabled as flow_temperature_interpolation_enabled_cls
from .zero_nodal_velocities_on_walls import zero_nodal_velocities_on_walls as zero_nodal_velocities_on_walls_cls

class interpolation(Group):
    fluent_name = ...
    child_names = ...
    flow_cp_interpolation_enabled: flow_cp_interpolation_enabled_cls = ...
    flow_density_interpolation_enabled: flow_density_interpolation_enabled_cls = ...
    flow_gradient_interpolation_enabled: flow_gradient_interpolation_enabled_cls = ...
    flow_viscosity_interpolation_enabled: flow_viscosity_interpolation_enabled_cls = ...
    flow_temperature_interpolation_enabled: flow_temperature_interpolation_enabled_cls = ...
    zero_nodal_velocities_on_walls: zero_nodal_velocities_on_walls_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .density_3 import density as density_cls
from .specific_heat_3 import specific_heat as specific_heat_cls
from .thermal_conductivity_3 import thermal_conductivity as thermal_conductivity_cls
from .thermophoretic_co import thermophoretic_co as thermophoretic_co_cls
from .scattering_factor import scattering_factor as scattering_factor_cls
from .emissivity import emissivity as emissivity_cls
from .viscosity_2 import viscosity as viscosity_cls
from .dpm_surften import dpm_surften as dpm_surften_cls
from .electric_conductivity_1 import electric_conductivity as electric_conductivity_cls
from .dual_electric_conductivity_1 import dual_electric_conductivity as dual_electric_conductivity_cls
from .magnetic_permeability import magnetic_permeability as magnetic_permeability_cls
from .charge_density import charge_density as charge_density_cls

class inert_particle_child(Group):
    """
    'child_object_type' of inert_particle.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['density', 'specific_heat', 'thermal_conductivity',
         'thermophoretic_co', 'scattering_factor', 'emissivity', 'viscosity',
         'dpm_surften', 'electric_conductivity', 'dual_electric_conductivity',
         'magnetic_permeability', 'charge_density']

    _child_classes = dict(
        density=density_cls,
        specific_heat=specific_heat_cls,
        thermal_conductivity=thermal_conductivity_cls,
        thermophoretic_co=thermophoretic_co_cls,
        scattering_factor=scattering_factor_cls,
        emissivity=emissivity_cls,
        viscosity=viscosity_cls,
        dpm_surften=dpm_surften_cls,
        electric_conductivity=electric_conductivity_cls,
        dual_electric_conductivity=dual_electric_conductivity_cls,
        magnetic_permeability=magnetic_permeability_cls,
        charge_density=charge_density_cls,
    )

    return_type = "<object object at 0x7fc5551a9850>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .execute_commands import execute_commands as execute_commands_cls
from .solution_animations import solution_animations as solution_animations_cls
from .poor_mesh_numerics import poor_mesh_numerics as poor_mesh_numerics_cls
from .enable_strategy import enable_strategy as enable_strategy_cls
from .copy_modification import copy_modification as copy_modification_cls
from .delete_modification import delete_modification as delete_modification_cls
from .enable_modification import enable_modification as enable_modification_cls
from .disable_modification import disable_modification as disable_modification_cls
from .import_modifications import import_modifications as import_modifications_cls
from .export_modifications import export_modifications as export_modifications_cls
from .continue_strategy_execution import continue_strategy_execution as continue_strategy_execution_cls

class calculation_activity(Group):
    """
    'calculation_activity' child.
    """

    fluent_name = "calculation-activity"

    child_names = \
        ['execute_commands', 'solution_animations', 'poor_mesh_numerics']

    command_names = \
        ['enable_strategy', 'copy_modification', 'delete_modification',
         'enable_modification', 'disable_modification',
         'import_modifications', 'export_modifications',
         'continue_strategy_execution']

    _child_classes = dict(
        execute_commands=execute_commands_cls,
        solution_animations=solution_animations_cls,
        poor_mesh_numerics=poor_mesh_numerics_cls,
        enable_strategy=enable_strategy_cls,
        copy_modification=copy_modification_cls,
        delete_modification=delete_modification_cls,
        enable_modification=enable_modification_cls,
        disable_modification=disable_modification_cls,
        import_modifications=import_modifications_cls,
        export_modifications=export_modifications_cls,
        continue_strategy_execution=continue_strategy_execution_cls,
    )

    return_type = "<object object at 0x7fb5f6080230>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .p_v_coupling import p_v_coupling as p_v_coupling_cls
from .flux_type_2 import flux_type as flux_type_cls
from .discretization_scheme import discretization_scheme as discretization_scheme_cls
from .pseudo_time_method import pseudo_time_method as pseudo_time_method_cls
from .unsteady_1st_order import unsteady_1st_order as unsteady_1st_order_cls
from .unsteady_2nd_order import unsteady_2nd_order as unsteady_2nd_order_cls
from .unsteady_2nd_order_bounded import unsteady_2nd_order_bounded as unsteady_2nd_order_bounded_cls
from .unsteady_global_time import unsteady_global_time as unsteady_global_time_cls
from .accelerated_non_iterative_time_marching import accelerated_non_iterative_time_marching as accelerated_non_iterative_time_marching_cls
from .convergence_acceleration_for_stretched_meshes_1 import convergence_acceleration_for_stretched_meshes as convergence_acceleration_for_stretched_meshes_cls
from .expert_1 import expert as expert_cls
from .frozen_flux import frozen_flux as frozen_flux_cls
from .gradient_scheme import gradient_scheme as gradient_scheme_cls
from .high_order_term_relaxation import high_order_term_relaxation as high_order_term_relaxation_cls
from .multiphase_numerics import multiphase_numerics as multiphase_numerics_cls
from .nb_gradient_boundary_option import nb_gradient_boundary_option as nb_gradient_boundary_option_cls
from .nita import nita as nita_cls
from .nita_expert_controls import nita_expert_controls as nita_expert_controls_cls
from .overset_1 import overset as overset_cls
from .phase_based_vof_discretization import phase_based_vof_discretization as phase_based_vof_discretization_cls
from .reduced_rank_extrapolation import reduced_rank_extrapolation as reduced_rank_extrapolation_cls
from .reduced_rank_extrapolation_options import reduced_rank_extrapolation_options as reduced_rank_extrapolation_options_cls
from .residual_smoothing import residual_smoothing as residual_smoothing_cls
from .vof_numerics import vof_numerics as vof_numerics_cls
from .warped_face_gradient_correction import warped_face_gradient_correction as warped_face_gradient_correction_cls
from .set_solution_methods_to_default import set_solution_methods_to_default as set_solution_methods_to_default_cls

class methods(Group):
    fluent_name = ...
    child_names = ...
    p_v_coupling: p_v_coupling_cls = ...
    flux_type: flux_type_cls = ...
    discretization_scheme: discretization_scheme_cls = ...
    pseudo_time_method: pseudo_time_method_cls = ...
    unsteady_1st_order: unsteady_1st_order_cls = ...
    unsteady_2nd_order: unsteady_2nd_order_cls = ...
    unsteady_2nd_order_bounded: unsteady_2nd_order_bounded_cls = ...
    unsteady_global_time: unsteady_global_time_cls = ...
    accelerated_non_iterative_time_marching: accelerated_non_iterative_time_marching_cls = ...
    convergence_acceleration_for_stretched_meshes: convergence_acceleration_for_stretched_meshes_cls = ...
    expert: expert_cls = ...
    frozen_flux: frozen_flux_cls = ...
    gradient_scheme: gradient_scheme_cls = ...
    high_order_term_relaxation: high_order_term_relaxation_cls = ...
    multiphase_numerics: multiphase_numerics_cls = ...
    nb_gradient_boundary_option: nb_gradient_boundary_option_cls = ...
    nita: nita_cls = ...
    nita_expert_controls: nita_expert_controls_cls = ...
    overset: overset_cls = ...
    phase_based_vof_discretization: phase_based_vof_discretization_cls = ...
    reduced_rank_extrapolation: reduced_rank_extrapolation_cls = ...
    reduced_rank_extrapolation_options: reduced_rank_extrapolation_options_cls = ...
    residual_smoothing: residual_smoothing_cls = ...
    vof_numerics: vof_numerics_cls = ...
    warped_face_gradient_correction: warped_face_gradient_correction_cls = ...
    command_names = ...

    def set_solution_methods_to_default(self, ):
        """
        Set solution methods to default values.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .ablation_select_model import ablation_select_model as ablation_select_model_cls
from .ablation_vielle_a import ablation_vielle_a as ablation_vielle_a_cls
from .ablation_vielle_n import ablation_vielle_n as ablation_vielle_n_cls
from .ablation_flux import ablation_flux as ablation_flux_cls
from .ablation_surfacerxn_density import ablation_surfacerxn_density as ablation_surfacerxn_density_cls
from .ablation_species_mf import ablation_species_mf as ablation_species_mf_cls

class ablation(Group):
    """
    Help not available.
    """

    fluent_name = "ablation"

    child_names = \
        ['ablation_select_model', 'ablation_vielle_a', 'ablation_vielle_n',
         'ablation_flux', 'ablation_surfacerxn_density',
         'ablation_species_mf']

    _child_classes = dict(
        ablation_select_model=ablation_select_model_cls,
        ablation_vielle_a=ablation_vielle_a_cls,
        ablation_vielle_n=ablation_vielle_n_cls,
        ablation_flux=ablation_flux_cls,
        ablation_surfacerxn_density=ablation_surfacerxn_density_cls,
        ablation_species_mf=ablation_species_mf_cls,
    )

    return_type = "<object object at 0x7f766ac613e0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .sc_def_file_settings import sc_def_file_settings as sc_def_file_settings_cls
from .settings import settings as settings_cls
from .abaqus import abaqus as abaqus_cls
from .mechanical_apdl import mechanical_apdl as mechanical_apdl_cls
from .mechanical_apdl_input import mechanical_apdl_input as mechanical_apdl_input_cls
from .ascii import ascii as ascii_cls
from .avs import avs as avs_cls
from .ensight import ensight as ensight_cls
from .ensight_gold import ensight_gold as ensight_gold_cls
from .fieldview import fieldview as fieldview_cls
from .fieldview_data import fieldview_data as fieldview_data_cls
from .gambit import gambit as gambit_cls
from .cgns import cgns as cgns_cls
from .custom_heat_flux import custom_heat_flux as custom_heat_flux_cls
from .dx import dx as dx_cls
from .ensight_gold_parallel_surfaces import ensight_gold_parallel_surfaces as ensight_gold_parallel_surfaces_cls
from .ensight_gold_parallel_volume import ensight_gold_parallel_volume as ensight_gold_parallel_volume_cls
from .icemcfd_for_icepak import icemcfd_for_icepak as icemcfd_for_icepak_cls
from .fast_mesh import fast_mesh as fast_mesh_cls
from .fast_solution import fast_solution as fast_solution_cls
from .fast_velocity import fast_velocity as fast_velocity_cls
from .taitherm import taitherm as taitherm_cls
from .fieldview_unstruct import fieldview_unstruct as fieldview_unstruct_cls
from .fieldview_unstruct_mesh import fieldview_unstruct_mesh as fieldview_unstruct_mesh_cls
from .fieldview_unstruct_data import fieldview_unstruct_data as fieldview_unstruct_data_cls
from .fieldview_unstruct_surfaces import fieldview_unstruct_surfaces as fieldview_unstruct_surfaces_cls
from .ideas import ideas as ideas_cls
from .nastran import nastran as nastran_cls
from .patran_neutral import patran_neutral as patran_neutral_cls
from .patran_nodal import patran_nodal as patran_nodal_cls
from .tecplot import tecplot as tecplot_cls

class export(Group):
    fluent_name = ...
    child_names = ...
    sc_def_file_settings: sc_def_file_settings_cls = ...
    settings: settings_cls = ...
    command_names = ...

    def abaqus(self, name: str, surface_name_list: List[str], structural_analysis: bool, write_loads: bool, loads: List[str]):
        """
        Write an ABAQUS file.
        
        Parameters
        ----------
            name : str
                'name' child.
            surface_name_list : List
                'surface_name_list' child.
            structural_analysis : bool
                'structural_analysis' child.
            write_loads : bool
                'write_loads' child.
            loads : List
                'loads' child.
        
        """

    def mechanical_apdl(self, name: str, thread_name_list: List[str]):
        """
        Write an Mechanical APDL file.
        
        Parameters
        ----------
            name : str
                'name' child.
            thread_name_list : List
                'thread_name_list' child.
        
        """

    def mechanical_apdl_input(self, name: str, surface_name_list: List[str], structural_analysis: bool, write_loads: bool, loads: List[str]):
        """
        Write an Mechanical APDL Input file.
        
        Parameters
        ----------
            name : str
                'name' child.
            surface_name_list : List
                'surface_name_list' child.
            structural_analysis : bool
                'structural_analysis' child.
            write_loads : bool
                'write_loads' child.
            loads : List
                'loads' child.
        
        """

    def ascii(self, name: str, surface_name_list: List[str], delimiter: str, cell_func_domain: List[str], location: str):
        """
        Write an ASCII file.
        
        Parameters
        ----------
            name : str
                'name' child.
            surface_name_list : List
                List of surfaces to export.
            delimiter : str
                'delimiter' child.
            cell_func_domain : List
                'cell_func_domain' child.
            location : str
                'location' child.
        
        """

    def avs(self, name: str, cell_func_domain_export: List[str]):
        """
        Write an AVS UCD file.
        
        Parameters
        ----------
            name : str
                'name' child.
            cell_func_domain_export : List
                'cell_func_domain_export' child.
        
        """

    def ensight(self, name: str, cell_func_domain_export: List[str]):
        """
        Write EnSight 6 geometry, velocity, and scalar files.
        
        Parameters
        ----------
            name : str
                'name' child.
            cell_func_domain_export : List
                'cell_func_domain_export' child.
        
        """

    def ensight_gold(self, name: str, cell_func_domain_export: List[str]):
        """
        Write EnSight Gold geometry, velocity, and scalar files.
        
        Parameters
        ----------
            name : str
                'name' child.
            cell_func_domain_export : List
                'cell_func_domain_export' child.
        
        """

    def fieldview(self, name: str, cell_func_domain_export: List[str]):
        """
        Write Fieldview case and data files.
        
        Parameters
        ----------
            name : str
                'name' child.
            cell_func_domain_export : List
                'cell_func_domain_export' child.
        
        """

    def fieldview_data(self, name: str, cell_func_domain_export: List[str]):
        """
        Write Fieldview case and data files.
        
        Parameters
        ----------
            name : str
                'name' child.
            cell_func_domain_export : List
                'cell_func_domain_export' child.
        
        """

    def gambit(self, name: str, cell_func_domain_export: List[str]):
        """
        Write a Gambit neutral file.
        
        Parameters
        ----------
            name : str
                'name' child.
            cell_func_domain_export : List
                'cell_func_domain_export' child.
        
        """

    def cgns(self, name: str, scope: str, cell_zones: List[str], surfaces: List[str], cell_centered: bool, format_class: str, cgns_scalar: List[str]):
        """
        Write a CGNS file.
        
        Parameters
        ----------
            name : str
                'name' child.
            scope : str
                'scope' child.
            cell_zones : List
                'cell_zones' child.
            surfaces : List
                'surfaces' child.
            cell_centered : bool
                'cell_centered' child.
            format_class : str
                'format_class' child.
            cgns_scalar : List
                'cgns_scalar' child.
        
        """

    def custom_heat_flux(self, name: str, wall_function: bool, surface_name_list: List[str]):
        """
        Write a generic file for heat transfer.
        
        Parameters
        ----------
            name : str
                'name' child.
            wall_function : bool
                'wall_function' child.
            surface_name_list : List
                'surface_name_list' child.
        
        """

    def dx(self, name: str, surfaces: List[str], techplot_scalars: List[str]):
        """
        Write an IBM Data Explorer format file.
        
        Parameters
        ----------
            name : str
                'name' child.
            surfaces : List
                'surfaces' child.
            techplot_scalars : List
                'techplot_scalars' child.
        
        """

    def ensight_gold_parallel_surfaces(self, name: str, binary_format: bool, surfaces: List[str], cell_centered: bool, cell_function: List[str]):
        """
        Write EnSight Gold geometry, velocity and scalar files for surfaces. Fluent will write files suitable for EnSight Parallel.
        
        Parameters
        ----------
            name : str
                'name' child.
            binary_format : bool
                'binary_format' child.
            surfaces : List
                'surfaces' child.
            cell_centered : bool
                'cell_centered' child.
            cell_function : List
                'cell_function' child.
        
        """

    def ensight_gold_parallel_volume(self, name: str, binary_format: bool, cellzones: List[str], cell_centered: bool, cell_function: List[str]):
        """
        Write EnSight Gold geometry, velocity and scalar files for cell zones and boundaries attached to them. Fluent will write files suitable for EnSight Parallel.
        
        Parameters
        ----------
            name : str
                'name' child.
            binary_format : bool
                'binary_format' child.
            cellzones : List
                'cellzones' child.
            cell_centered : bool
                'cell_centered' child.
            cell_function : List
                'cell_function' child.
        
        """

    def icemcfd_for_icepak(self, name: str):
        """
        Write a binary ICEMCFD domain file.
        
        Parameters
        ----------
            name : str
                'name' child.
        
        """

    def fast_mesh(self, name: str):
        """
        Write a FAST/Plot3D unstructured mesh file.
        
        Parameters
        ----------
            name : str
                'name' child.
        
        """

    def fast_solution(self, name: str):
        """
        Write a FAST/Plot3D unstructured solution file.
        
        Parameters
        ----------
            name : str
                'name' child.
        
        """

    def fast_velocity(self, name: str):
        """
        Write a FAST/Plot3D unstructured vector function file.
        
        Parameters
        ----------
            name : str
                'name' child.
        
        """

    def taitherm(self, name: str, surface_name_list: List[str], wall_function: bool, htc_on_walls: bool):
        """
        Write a TAITherm file.
        
        Parameters
        ----------
            name : str
                'name' child.
            surface_name_list : List
                'surface_name_list' child.
            wall_function : bool
                'wall_function' child.
            htc_on_walls : bool
                'htc_on_walls' child.
        
        """

    def fieldview_unstruct(self, name: str, surfaces: List[str], cellzones: List[str], cell_func_domain: List[str]):
        """
        Write a Fieldview unstructured combined file.
        
        Parameters
        ----------
            name : str
                'name' child.
            surfaces : List
                List of surfaces to export.
            cellzones : List
                List of cell zones to export.
            cell_func_domain : List
                'cell_func_domain' child.
        
        """

    def fieldview_unstruct_mesh(self, name: str, surfaces: List[str], cellzones: List[str], cell_func_domain: List[str]):
        """
        Write a Fieldview unstructured mesh only file.
        
        Parameters
        ----------
            name : str
                'name' child.
            surfaces : List
                List of surfaces to export.
            cellzones : List
                List of cell zones to export.
            cell_func_domain : List
                'cell_func_domain' child.
        
        """

    def fieldview_unstruct_data(self, name: str, surfaces: List[str], cellzones: List[str], cell_func_domain: List[str]):
        """
        Write a Fieldview unstructured results only file.
        
        Parameters
        ----------
            name : str
                'name' child.
            surfaces : List
                List of surfaces to export.
            cellzones : List
                List of cell zones to export.
            cell_func_domain : List
                'cell_func_domain' child.
        
        """

    def fieldview_unstruct_surfaces(self, options: str, name: str, surfaces: List[str], cell_func_domain: List[str]):
        """
        Write a Fieldview unstructured surface mesh, data.
        
        Parameters
        ----------
            options : str
                'options' child.
            name : str
                'name' child.
            surfaces : List
                'surfaces' child.
            cell_func_domain : List
                'cell_func_domain' child.
        
        """

    def ideas(self, name: str, surfaces: List[str], structural_analysis: bool, write_loads: bool, loads: List[str], cell_func_domain_export: List[str]):
        """
        Write an IDEAS universal file.
        
        Parameters
        ----------
            name : str
                'name' child.
            surfaces : List
                List of surfaces to export.
            structural_analysis : bool
                'structural_analysis' child.
            write_loads : bool
                'write_loads' child.
            loads : List
                'loads' child.
            cell_func_domain_export : List
                'cell_func_domain_export' child.
        
        """

    def nastran(self, name: str, bndry_threads: List[str], surfaces: List[str], structural_analysis: bool, write_loads: bool, loads: List[str], cell_func_domain_export: List[str]):
        """
        Write a NASTRAN file.
        
        Parameters
        ----------
            name : str
                'name' child.
            bndry_threads : List
                'bndry_threads' child.
            surfaces : List
                'surfaces' child.
            structural_analysis : bool
                'structural_analysis' child.
            write_loads : bool
                'write_loads' child.
            loads : List
                'loads' child.
            cell_func_domain_export : List
                'cell_func_domain_export' child.
        
        """

    def patran_neutral(self, name: str, surfaces: List[str], structural_analysis: bool, write_loads: bool, loads: List[str], cell_func_domain_export: List[str]):
        """
        Write a PATRAN neutral file.
        
        Parameters
        ----------
            name : str
                'name' child.
            surfaces : List
                'surfaces' child.
            structural_analysis : bool
                'structural_analysis' child.
            write_loads : bool
                'write_loads' child.
            loads : List
                'loads' child.
            cell_func_domain_export : List
                'cell_func_domain_export' child.
        
        """

    def patran_nodal(self, name: str, surfaces: List[str], cell_func_domain_export: List[str]):
        """
        Write a PATRAN nodal results file.
        
        Parameters
        ----------
            name : str
                'name' child.
            surfaces : List
                'surfaces' child.
            cell_func_domain_export : List
                'cell_func_domain_export' child.
        
        """

    def tecplot(self, name: str, surfaces: List[str], cell_func_domain_export: List[str]):
        """
        Write a Tecplot+3DV format file.
        
        Parameters
        ----------
            name : str
                'name' child.
            surfaces : List
                'surfaces' child.
            cell_func_domain_export : List
                'cell_func_domain_export' child.
        
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .thickness import thickness as thickness_cls
from .material import material as material_cls
from .qdot import qdot as qdot_cls

class shell_conduction_child(Group):
    fluent_name = ...
    child_names = ...
    thickness: thickness_cls = ...
    material: material_cls = ...
    qdot: qdot_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .input_parameters import input_parameters as input_parameters_cls
from .output_parameters import output_parameters as output_parameters_cls
from .write_data_1 import write_data as write_data_cls
from .capture_simulation_report_data_1 import capture_simulation_report_data as capture_simulation_report_data_cls

class design_points_child(Group):
    """
    'child_object_type' of design_points.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['input_parameters', 'output_parameters', 'write_data',
         'capture_simulation_report_data']

    _child_classes = dict(
        input_parameters=input_parameters_cls,
        output_parameters=output_parameters_cls,
        write_data=write_data_cls,
        capture_simulation_report_data=capture_simulation_report_data_cls,
    )

    return_type = "<object object at 0x7fb5f5f73c30>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .counter_clockwise import counter_clockwise as counter_clockwise_cls

class roll(Command):
    """
    Adjust the camera up-vector.
    
    Parameters
    ----------
        counter_clockwise : real
            'counter_clockwise' child.
    
    """

    fluent_name = "roll"

    argument_names = \
        ['counter_clockwise']

    _child_classes = dict(
        counter_clockwise=counter_clockwise_cls,
    )

    return_type = "<object object at 0x7fd82ad48f20>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .minimum_val import minimum_val as minimum_val_cls
from .maximum_val import maximum_val as maximum_val_cls
from .division_val import division_val as division_val_cls

class histogram_parameters(Group):
    """
    Enter the parameter menu for the histogram.
    """

    fluent_name = "histogram-parameters"

    child_names = \
        ['minimum_val', 'maximum_val', 'division_val']

    _child_classes = dict(
        minimum_val=minimum_val_cls,
        maximum_val=maximum_val_cls,
        division_val=division_val_cls,
    )

    return_type = "<object object at 0x7fc55413f9e0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .phase_4 import phase as phase_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .porous_jump_turb_wall_treatment import porous_jump_turb_wall_treatment as porous_jump_turb_wall_treatment_cls
from .dir import dir as dir_cls
from .average_dp import average_dp as average_dp_cls
from .c_1 import c as c_cls
from .limit_range import limit_range as limit_range_cls
from .v_min import v_min as v_min_cls
from .v_max import v_max as v_max_cls
from .strength import strength as strength_cls
from .profile_dp import profile_dp as profile_dp_cls
from .dp_profile import dp_profile as dp_profile_cls
from .swirl_model import swirl_model as swirl_model_cls
from .fan_vr import fan_vr as fan_vr_cls
from .fr import fr as fr_cls
from .hub import hub as hub_cls
from .axis_origin_2 import axis_origin as axis_origin_cls
from .axis_direction_2 import axis_direction as axis_direction_cls
from .profile_vt import profile_vt as profile_vt_cls
from .vt_profile import vt_profile as vt_profile_cls
from .profile_vr import profile_vr as profile_vr_cls
from .vr_profile import vr_profile as vr_profile_cls
from .swirl_factor import swirl_factor as swirl_factor_cls
from .dpm_bc_type import dpm_bc_type as dpm_bc_type_cls
from .dpm_bc_collision_partner import dpm_bc_collision_partner as dpm_bc_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_udf import dpm_bc_udf as dpm_bc_udf_cls
from .new_fan_definition import new_fan_definition as new_fan_definition_cls

class fan_child(Group):
    fluent_name = ...
    child_names = ...
    phase: phase_cls = ...
    geom_disable: geom_disable_cls = ...
    geom_dir_spec: geom_dir_spec_cls = ...
    geom_dir_x: geom_dir_x_cls = ...
    geom_dir_y: geom_dir_y_cls = ...
    geom_dir_z: geom_dir_z_cls = ...
    geom_levels: geom_levels_cls = ...
    geom_bgthread: geom_bgthread_cls = ...
    porous_jump_turb_wall_treatment: porous_jump_turb_wall_treatment_cls = ...
    dir: dir_cls = ...
    average_dp: average_dp_cls = ...
    c: c_cls = ...
    limit_range: limit_range_cls = ...
    v_min: v_min_cls = ...
    v_max: v_max_cls = ...
    strength: strength_cls = ...
    profile_dp: profile_dp_cls = ...
    dp_profile: dp_profile_cls = ...
    swirl_model: swirl_model_cls = ...
    fan_vr: fan_vr_cls = ...
    fr: fr_cls = ...
    hub: hub_cls = ...
    axis_origin: axis_origin_cls = ...
    axis_direction: axis_direction_cls = ...
    profile_vt: profile_vt_cls = ...
    vt_profile: vt_profile_cls = ...
    profile_vr: profile_vr_cls = ...
    vr_profile: vr_profile_cls = ...
    swirl_factor: swirl_factor_cls = ...
    dpm_bc_type: dpm_bc_type_cls = ...
    dpm_bc_collision_partner: dpm_bc_collision_partner_cls = ...
    reinj_inj: reinj_inj_cls = ...
    dpm_bc_udf: dpm_bc_udf_cls = ...
    new_fan_definition: new_fan_definition_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option import option as option_cls
from .auto_range_on import auto_range_on as auto_range_on_cls
from .auto_range_off import auto_range_off as auto_range_off_cls

class range_option(Group):
    """
    'range_option' child.
    """

    fluent_name = "range-option"

    child_names = \
        ['option', 'auto_range_on', 'auto_range_off']

    _child_classes = dict(
        option=option_cls,
        auto_range_on=auto_range_on_cls,
        auto_range_off=auto_range_off_cls,
    )

    return_type = "<object object at 0x7fd82ae3b550>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .coupled_vof import coupled_vof as coupled_vof_cls
from .rhie_chow_flux import rhie_chow_flux as rhie_chow_flux_cls
from .skewness_correction import skewness_correction as skewness_correction_cls

class p_v_coupling(Group):
    """
    'p_v_coupling' child.
    """

    fluent_name = "p-v-coupling"

    child_names = \
        ['coupled_vof', 'rhie_chow_flux', 'skewness_correction']

    _child_classes = dict(
        coupled_vof=coupled_vof_cls,
        rhie_chow_flux=rhie_chow_flux_cls,
        skewness_correction=skewness_correction_cls,
    )

    return_type = "<object object at 0x7fd82ae395d0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .option import option as option_cls
from .constant import constant as constant_cls
from .boussinesq import boussinesq as boussinesq_cls
from .coefficients import coefficients as coefficients_cls
from .number_of_coefficients import number_of_coefficients as number_of_coefficients_cls
from .piecewise_polynomial import piecewise_polynomial as piecewise_polynomial_cls
from .nasa_9_piecewise_polynomial import nasa_9_piecewise_polynomial as nasa_9_piecewise_polynomial_cls
from .piecewise_linear import piecewise_linear as piecewise_linear_cls
from .anisotropic import anisotropic as anisotropic_cls
from .orthotropic import orthotropic as orthotropic_cls
from .var_class import var_class as var_class_cls

class scattering_coefficient(Group):
    fluent_name = ...
    child_names = ...
    option: option_cls = ...
    constant: constant_cls = ...
    boussinesq: boussinesq_cls = ...
    coefficients: coefficients_cls = ...
    number_of_coefficients: number_of_coefficients_cls = ...
    piecewise_polynomial: piecewise_polynomial_cls = ...
    nasa_9_piecewise_polynomial: nasa_9_piecewise_polynomial_cls = ...
    piecewise_linear: piecewise_linear_cls = ...
    anisotropic: anisotropic_cls = ...
    orthotropic: orthotropic_cls = ...
    var_class: var_class_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .d import d as d_cls
from .q_dot import q_dot as q_dot_cls
from .material import material as material_cls
from .thermal_bc import thermal_bc as thermal_bc_cls
from .t import t as t_cls
from .q import q as q_cls
from .h import h as h_cls
from .tinf_1 import tinf as tinf_cls
from .planar_conduction import planar_conduction as planar_conduction_cls
from .shell_conduction import shell_conduction as shell_conduction_cls
from .thin_wall import thin_wall as thin_wall_cls
from .motion_bc import motion_bc as motion_bc_cls
from .shear_bc import shear_bc as shear_bc_cls
from .rough_bc import rough_bc as rough_bc_cls
from .moving import moving as moving_cls
from .relative import relative as relative_cls
from .rotating import rotating as rotating_cls
from .vmag import vmag as vmag_cls
from .component_of_wall_translation import component_of_wall_translation as component_of_wall_translation_cls
from .components_1 import components as components_cls
from .x_velocity import x_velocity as x_velocity_cls
from .y_velocity import y_velocity as y_velocity_cls
from .z_velocity import z_velocity as z_velocity_cls
from .velocity_components import velocity_components as velocity_components_cls
from .in_emiss import in_emiss as in_emiss_cls
from .ex_emiss import ex_emiss as ex_emiss_cls
from .trad import trad as trad_cls
from .int_rad import int_rad as int_rad_cls
from .trad_internal import trad_internal as trad_internal_cls
from .area_enhancement_factor import area_enhancement_factor as area_enhancement_factor_cls
from .rough_option import rough_option as rough_option_cls
from .rough_nasa import rough_nasa as rough_nasa_cls
from .rough_shin_et_al import rough_shin_et_al as rough_shin_et_al_cls
from .rough_data import rough_data as rough_data_cls
from .roughness_height import roughness_height as roughness_height_cls
from .roughness_const import roughness_const as roughness_const_cls
from .roughness_height_cp import roughness_height_cp as roughness_height_cp_cls
from .roughness_const_cp import roughness_const_cp as roughness_const_cp_cls
from .roughness_const_nasa import roughness_const_nasa as roughness_const_nasa_cls
from .roughness_const_shin import roughness_const_shin as roughness_const_shin_cls
from .roughness_const_data import roughness_const_data as roughness_const_data_cls
from .variable_roughness import variable_roughness as variable_roughness_cls
from .free_stream_velocity import free_stream_velocity as free_stream_velocity_cls
from .free_stream_temp import free_stream_temp as free_stream_temp_cls
from .characteristic_length import characteristic_length as characteristic_length_cls
from .free_stream_temp_cp import free_stream_temp_cp as free_stream_temp_cp_cls
from .characteristic_length_cp import characteristic_length_cp as characteristic_length_cp_cls
from .liquid_content import liquid_content as liquid_content_cls
from .liquid_content_cp import liquid_content_cp as liquid_content_cp_cls
from .droplet_diameter import droplet_diameter as droplet_diameter_cls
from .dpm_bc_type import dpm_bc_type as dpm_bc_type_cls
from .dpm_bc_collision_partner import dpm_bc_collision_partner as dpm_bc_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_norm_coeff import dpm_bc_norm_coeff as dpm_bc_norm_coeff_cls
from .dpm_bc_tang_coeff import dpm_bc_tang_coeff as dpm_bc_tang_coeff_cls
from .dpm_bc_frictn_coeff import dpm_bc_frictn_coeff as dpm_bc_frictn_coeff_cls
from .dpm_bc_udf import dpm_bc_udf as dpm_bc_udf_cls
from .dpm_film_splash_nsamp import dpm_film_splash_nsamp as dpm_film_splash_nsamp_cls
from .dpm_crit_temp_option import dpm_crit_temp_option as dpm_crit_temp_option_cls
from .dpm_critical_temp_factor import dpm_critical_temp_factor as dpm_critical_temp_factor_cls
from .dpm_calibratable_temp import dpm_calibratable_temp as dpm_calibratable_temp_cls
from .dpm_impingement_splashing_model import dpm_impingement_splashing_model as dpm_impingement_splashing_model_cls
from .dpm_upper_deposition_limit_offset import dpm_upper_deposition_limit_offset as dpm_upper_deposition_limit_offset_cls
from .dpm_deposition_delta_t import dpm_deposition_delta_t as dpm_deposition_delta_t_cls
from .dpm_laplace_number_constant import dpm_laplace_number_constant as dpm_laplace_number_constant_cls
from .dpm_partial_evaporation_ratio import dpm_partial_evaporation_ratio as dpm_partial_evaporation_ratio_cls
from .ra_roughness import ra_roughness as ra_roughness_cls
from .rz_roughness import rz_roughness as rz_roughness_cls
from .rq_roughness import rq_roughness as rq_roughness_cls
from .rsm_roughness import rsm_roughness as rsm_roughness_cls
from .dpm_bc_erosion_generic import dpm_bc_erosion_generic as dpm_bc_erosion_generic_cls
from .dpm_bc_erosion import dpm_bc_erosion as dpm_bc_erosion_cls
from .dpm_bc_erosion_c import dpm_bc_erosion_c as dpm_bc_erosion_c_cls
from .dpm_bc_erosion_n import dpm_bc_erosion_n as dpm_bc_erosion_n_cls
from .dpm_bc_erosion_finnie import dpm_bc_erosion_finnie as dpm_bc_erosion_finnie_cls
from .dpm_bc_erosion_finnie_k import dpm_bc_erosion_finnie_k as dpm_bc_erosion_finnie_k_cls
from .dpm_bc_erosion_finnie_vel_exp import dpm_bc_erosion_finnie_vel_exp as dpm_bc_erosion_finnie_vel_exp_cls
from .dpm_bc_erosion_finnie_max_erosion_angle import dpm_bc_erosion_finnie_max_erosion_angle as dpm_bc_erosion_finnie_max_erosion_angle_cls
from .dpm_bc_erosion_mclaury import dpm_bc_erosion_mclaury as dpm_bc_erosion_mclaury_cls
from .dpm_bc_erosion_mclaury_a import dpm_bc_erosion_mclaury_a as dpm_bc_erosion_mclaury_a_cls
from .dpm_bc_erosion_mclaury_vel_exp import dpm_bc_erosion_mclaury_vel_exp as dpm_bc_erosion_mclaury_vel_exp_cls
from .dpm_bc_erosion_mclaury_transition_angle import dpm_bc_erosion_mclaury_transition_angle as dpm_bc_erosion_mclaury_transition_angle_cls
from .dpm_bc_erosion_mclaury_b import dpm_bc_erosion_mclaury_b as dpm_bc_erosion_mclaury_b_cls
from .dpm_bc_erosion_mclaury_c import dpm_bc_erosion_mclaury_c as dpm_bc_erosion_mclaury_c_cls
from .dpm_bc_erosion_mclaury_w import dpm_bc_erosion_mclaury_w as dpm_bc_erosion_mclaury_w_cls
from .dpm_bc_erosion_mclaury_x import dpm_bc_erosion_mclaury_x as dpm_bc_erosion_mclaury_x_cls
from .dpm_bc_erosion_mclaury_y import dpm_bc_erosion_mclaury_y as dpm_bc_erosion_mclaury_y_cls
from .dpm_bc_erosion_oka import dpm_bc_erosion_oka as dpm_bc_erosion_oka_cls
from .dpm_bc_erosion_oka_e90 import dpm_bc_erosion_oka_e90 as dpm_bc_erosion_oka_e90_cls
from .dpm_bc_erosion_oka_hv import dpm_bc_erosion_oka_hv as dpm_bc_erosion_oka_hv_cls
from .dpm_bc_erosion_oka_n1 import dpm_bc_erosion_oka_n1 as dpm_bc_erosion_oka_n1_cls
from .dpm_bc_erosion_oka_n2 import dpm_bc_erosion_oka_n2 as dpm_bc_erosion_oka_n2_cls
from .dpm_bc_erosion_oka_k2 import dpm_bc_erosion_oka_k2 as dpm_bc_erosion_oka_k2_cls
from .dpm_bc_erosion_oka_k3 import dpm_bc_erosion_oka_k3 as dpm_bc_erosion_oka_k3_cls
from .dpm_bc_erosion_oka_dref import dpm_bc_erosion_oka_dref as dpm_bc_erosion_oka_dref_cls
from .dpm_bc_erosion_oka_vref import dpm_bc_erosion_oka_vref as dpm_bc_erosion_oka_vref_cls
from .dpm_bc_erosion_dnv import dpm_bc_erosion_dnv as dpm_bc_erosion_dnv_cls
from .dpm_bc_erosion_dnv_k import dpm_bc_erosion_dnv_k as dpm_bc_erosion_dnv_k_cls
from .dpm_bc_erosion_dnv_n import dpm_bc_erosion_dnv_n as dpm_bc_erosion_dnv_n_cls
from .dpm_bc_erosion_dnv_ductile import dpm_bc_erosion_dnv_ductile as dpm_bc_erosion_dnv_ductile_cls
from .dpm_bc_erosion_shear import dpm_bc_erosion_shear as dpm_bc_erosion_shear_cls
from .dpm_bc_erosion_shear_v import dpm_bc_erosion_shear_v as dpm_bc_erosion_shear_v_cls
from .dpm_bc_erosion_shear_c import dpm_bc_erosion_shear_c as dpm_bc_erosion_shear_c_cls
from .dpm_bc_erosion_shear_packing_limit import dpm_bc_erosion_shear_packing_limit as dpm_bc_erosion_shear_packing_limit_cls
from .dpm_bc_erosion_shielding import dpm_bc_erosion_shielding as dpm_bc_erosion_shielding_cls
from .dpm_wall_heat_exchange import dpm_wall_heat_exchange as dpm_wall_heat_exchange_cls
from .dpm_film_condensation import dpm_film_condensation as dpm_film_condensation_cls
from .dpm_film_bl_model import dpm_film_bl_model as dpm_film_bl_model_cls
from .dpm_particle_stripping import dpm_particle_stripping as dpm_particle_stripping_cls
from .dpm_critical_shear_stress import dpm_critical_shear_stress as dpm_critical_shear_stress_cls
from .dpm_film_separation_model import dpm_film_separation_model as dpm_film_separation_model_cls
from .dpm_critical_we_number import dpm_critical_we_number as dpm_critical_we_number_cls
from .dpm_film_separation_angle import dpm_film_separation_angle as dpm_film_separation_angle_cls
from .dpm_allow_lwf_to_vof import dpm_allow_lwf_to_vof as dpm_allow_lwf_to_vof_cls
from .dpm_allow_vof_to_lwf import dpm_allow_vof_to_lwf as dpm_allow_vof_to_lwf_cls
from .dpm_initialize_lwf import dpm_initialize_lwf as dpm_initialize_lwf_cls
from .dpm_initial_height import dpm_initial_height as dpm_initial_height_cls
from .film_velocity import film_velocity as film_velocity_cls
from .dpm_initial_temperature import dpm_initial_temperature as dpm_initial_temperature_cls
from .dpm_initial_injection import dpm_initial_injection as dpm_initial_injection_cls
from .film_parcel_surface_area_density import film_parcel_surface_area_density as film_parcel_surface_area_density_cls
from .minimum_number_of_parcels_per_face import minimum_number_of_parcels_per_face as minimum_number_of_parcels_per_face_cls
from .band_in_emiss import band_in_emiss as band_in_emiss_cls
from .radiation_bc import radiation_bc as radiation_bc_cls
from .mc_bsource_p import mc_bsource_p as mc_bsource_p_cls
from .mc_poldfun_p import mc_poldfun_p as mc_poldfun_p_cls
from .polar_func_type import polar_func_type as polar_func_type_cls
from .mc_polar_expr import mc_polar_expr as mc_polar_expr_cls
from .polar_pair_list import polar_pair_list as polar_pair_list_cls
from .pold_pair_list_rad import pold_pair_list_rad as pold_pair_list_rad_cls
from .component_of_radiation_direction import component_of_radiation_direction as component_of_radiation_direction_cls
from .coll_dtheta import coll_dtheta as coll_dtheta_cls
from .coll_dphi import coll_dphi as coll_dphi_cls
from .band_q_irrad import band_q_irrad as band_q_irrad_cls
from .band_q_irrad_diffuse import band_q_irrad_diffuse as band_q_irrad_diffuse_cls
from .band_diffuse_frac import band_diffuse_frac as band_diffuse_frac_cls
from .radiating_s2s_surface import radiating_s2s_surface as radiating_s2s_surface_cls
from .critical_zone import critical_zone as critical_zone_cls
from .fpsc import fpsc as fpsc_cls
from .parallel_collimated_beam import parallel_collimated_beam as parallel_collimated_beam_cls
from .solar_fluxes import solar_fluxes as solar_fluxes_cls
from .solar_direction import solar_direction as solar_direction_cls
from .solar_irradiation import solar_irradiation as solar_irradiation_cls
from .v_transmissivity import v_transmissivity as v_transmissivity_cls
from .ir_transmissivity import ir_transmissivity as ir_transmissivity_cls
from .v_opq_absorbtivity import v_opq_absorbtivity as v_opq_absorbtivity_cls
from .ir_opq_absorbtivity import ir_opq_absorbtivity as ir_opq_absorbtivity_cls
from .v_st_absorbtivity import v_st_absorbtivity as v_st_absorbtivity_cls
from .ir_st_absorbtivity import ir_st_absorbtivity as ir_st_absorbtivity_cls
from .d_st_absorbtivity import d_st_absorbtivity as d_st_absorbtivity_cls
from .d_transmissivity import d_transmissivity as d_transmissivity_cls
from .fsi_interface import fsi_interface as fsi_interface_cls
from .react import react as react_cls
from .partially_catalytic import partially_catalytic as partially_catalytic_cls
from .partially_catalytic_material import partially_catalytic_material as partially_catalytic_material_cls
from .partially_catalytic_recombination_coefficient_o import partially_catalytic_recombination_coefficient_o as partially_catalytic_recombination_coefficient_o_cls
from .partially_catalytic_recombination_coefficient_n import partially_catalytic_recombination_coefficient_n as partially_catalytic_recombination_coefficient_n_cls
from .partially_catalytic_recombination_model import partially_catalytic_recombination_model as partially_catalytic_recombination_model_cls
from .species_spec import species_spec as species_spec_cls
from .mf import mf as mf_cls
from .elec_potential_type import elec_potential_type as elec_potential_type_cls
from .potential_value import potential_value as potential_value_cls
from .elec_potential_jump import elec_potential_jump as elec_potential_jump_cls
from .elec_potential_resistance import elec_potential_resistance as elec_potential_resistance_cls
from .dual_potential_type import dual_potential_type as dual_potential_type_cls
from .dual_potential_value import dual_potential_value as dual_potential_value_cls
from .echem_reaction import echem_reaction as echem_reaction_cls
from .elec_potential_mechs import elec_potential_mechs as elec_potential_mechs_cls
from .faradaic_heat import faradaic_heat as faradaic_heat_cls
from .li_ion_type import li_ion_type as li_ion_type_cls
from .li_ion_value import li_ion_value as li_ion_value_cls
from .x_displacement_type import x_displacement_type as x_displacement_type_cls
from .x_displacement_value import x_displacement_value as x_displacement_value_cls
from .y_displacement_type import y_displacement_type as y_displacement_type_cls
from .y_displacement_value import y_displacement_value as y_displacement_value_cls
from .z_displacement_type import z_displacement_type as z_displacement_type_cls
from .z_displacement_value import z_displacement_value as z_displacement_value_cls
from .per_dispx import per_dispx as per_dispx_cls
from .per_dispy import per_dispy as per_dispy_cls
from .per_dispz import per_dispz as per_dispz_cls
from .per_imagx import per_imagx as per_imagx_cls
from .per_imagy import per_imagy as per_imagy_cls
from .per_imagz import per_imagz as per_imagz_cls
from .freq import freq as freq_cls
from .amp import amp as amp_cls
from .nodal_diam import nodal_diam as nodal_diam_cls
from .pass_number import pass_number as pass_number_cls
from .fwd import fwd as fwd_cls
from .aero import aero as aero_cls
from .cmplx import cmplx as cmplx_cls
from .norm import norm as norm_cls
from .method_1 import method as method_cls
from .uds_bc import uds_bc as uds_bc_cls
from .uds import uds as uds_cls
from .gtemp_bc import gtemp_bc as gtemp_bc_cls
from .g_temperature import g_temperature as g_temperature_cls
from .g_qflux import g_qflux as g_qflux_cls
from .wall_restitution_coeff import wall_restitution_coeff as wall_restitution_coeff_cls
from .omega import omega as omega_cls
from .origin_position_of_rotation_axis import origin_position_of_rotation_axis as origin_position_of_rotation_axis_cls
from .direction_component_of_rotation_axis import direction_component_of_rotation_axis as direction_component_of_rotation_axis_cls
from .adhesion_angle import adhesion_angle as adhesion_angle_cls
from .specified_shear import specified_shear as specified_shear_cls
from .shear_y import shear_y as shear_y_cls
from .shear_z import shear_z as shear_z_cls
from .shear_stress_components import shear_stress_components as shear_stress_components_cls
from .fslip import fslip as fslip_cls
from .eslip import eslip as eslip_cls
from .surf_tens_grad import surf_tens_grad as surf_tens_grad_cls
from .contact_resistance import contact_resistance as contact_resistance_cls
from .reaction_mechs_1 import reaction_mechs as reaction_mechs_cls
from .surf_washcoat_factor import surf_washcoat_factor as surf_washcoat_factor_cls
from .ablation_select_model import ablation_select_model as ablation_select_model_cls
from .ablation_vielle_a import ablation_vielle_a as ablation_vielle_a_cls
from .ablation_vielle_n import ablation_vielle_n as ablation_vielle_n_cls
from .ablation_surfacerxn_density import ablation_surfacerxn_density as ablation_surfacerxn_density_cls
from .ablation_flux import ablation_flux as ablation_flux_cls
from .ablation_species_mf import ablation_species_mf as ablation_species_mf_cls
from .specular_coeff import specular_coeff as specular_coeff_cls
from .mom_accom_coef import mom_accom_coef as mom_accom_coef_cls
from .therm_accom_coef import therm_accom_coef as therm_accom_coef_cls
from .eve_accom_coef import eve_accom_coef as eve_accom_coef_cls
from .film_wall import film_wall as film_wall_cls
from .film_wall_bc import film_wall_bc as film_wall_bc_cls
from .film_height import film_height as film_height_cls
from .flux_momentum_components import flux_momentum_components as flux_momentum_components_cls
from .film_relative_vel import film_relative_vel as film_relative_vel_cls
from .film_bc_imp_press import film_bc_imp_press as film_bc_imp_press_cls
from .film_temperature import film_temperature as film_temperature_cls
from .film_scalar import film_scalar as film_scalar_cls
from .film_source import film_source as film_source_cls
from .film_h_src import film_h_src as film_h_src_cls
from .film_u_src import film_u_src as film_u_src_cls
from .film_v_src import film_v_src as film_v_src_cls
from .film_w_src import film_w_src as film_w_src_cls
from .momentum_source_components import momentum_source_components as momentum_source_components_cls
from .film_t_src import film_t_src as film_t_src_cls
from .film_s_src import film_s_src as film_s_src_cls
from .film_phase_change import film_phase_change as film_phase_change_cls
from .film_phase_change_model import film_phase_change_model as film_phase_change_model_cls
from .film_cond_const import film_cond_const as film_cond_const_cls
from .film_vapo_const import film_vapo_const as film_vapo_const_cls
from .film_cond_rate import film_cond_rate as film_cond_rate_cls
from .film_vapo_rate import film_vapo_rate as film_vapo_rate_cls
from .film_momentum_coupling import film_momentum_coupling as film_momentum_coupling_cls
from .film_splash_wall import film_splash_wall as film_splash_wall_cls
from .film_boundary_separation import film_boundary_separation as film_boundary_separation_cls
from .film_impinge_model import film_impinge_model as film_impinge_model_cls
from .film_splash_nparc import film_splash_nparc as film_splash_nparc_cls
from .film_crit_temp_factor import film_crit_temp_factor as film_crit_temp_factor_cls
from .film_roughness_ra import film_roughness_ra as film_roughness_ra_cls
from .film_roughness_rz import film_roughness_rz as film_roughness_rz_cls
from .film_upper_deposition_limit_offset import film_upper_deposition_limit_offset as film_upper_deposition_limit_offset_cls
from .film_deposition_delta_t import film_deposition_delta_t as film_deposition_delta_t_cls
from .film_laplace_number_constant import film_laplace_number_constant as film_laplace_number_constant_cls
from .film_partial_evap_ratio import film_partial_evap_ratio as film_partial_evap_ratio_cls
from .film_contact_angle import film_contact_angle as film_contact_angle_cls
from .film_contact_angle_mean import film_contact_angle_mean as film_contact_angle_mean_cls
from .film_contact_angle_rstd import film_contact_angle_rstd as film_contact_angle_rstd_cls
from .film_contact_angle_beta import film_contact_angle_beta as film_contact_angle_beta_cls
from .film_vof_coupling_high import film_vof_coupling_high as film_vof_coupling_high_cls
from .film_vof_trans_high import film_vof_trans_high as film_vof_trans_high_cls
from .film_vof_trans_high_relax import film_vof_trans_high_relax as film_vof_trans_high_relax_cls
from .film_vof_coupling_low import film_vof_coupling_low as film_vof_coupling_low_cls
from .film_vof_trans_low import film_vof_trans_low as film_vof_trans_low_cls
from .film_vof_trans_low_relax import film_vof_trans_low_relax as film_vof_trans_low_relax_cls
from .caf import caf as caf_cls
from .thermal_stabilization import thermal_stabilization as thermal_stabilization_cls
from .scale_factor import scale_factor as scale_factor_cls
from .stab_method import stab_method as stab_method_cls
from .fensapice_ice_icing_mode import fensapice_ice_icing_mode as fensapice_ice_icing_mode_cls
from .fensapice_ice_hflux import fensapice_ice_hflux as fensapice_ice_hflux_cls
from .fensapice_ice_hflux_1 import fensapice_ice_hflux_1 as fensapice_ice_hflux_1_cls
from .fensapice_drop_vwet import fensapice_drop_vwet as fensapice_drop_vwet_cls

class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'd', 'q_dot',
         'material', 'thermal_bc', 't', 'q', 'h', 'tinf', 'planar_conduction',
         'shell_conduction', 'thin_wall', 'motion_bc', 'shear_bc', 'rough_bc',
         'moving', 'relative', 'rotating', 'vmag',
         'component_of_wall_translation', 'components', 'x_velocity',
         'y_velocity', 'z_velocity', 'velocity_components', 'in_emiss',
         'ex_emiss', 'trad', 'int_rad', 'trad_internal',
         'area_enhancement_factor', 'rough_option', 'rough_nasa',
         'rough_shin_et_al', 'rough_data', 'roughness_height',
         'roughness_const', 'roughness_height_cp', 'roughness_const_cp',
         'roughness_const_nasa', 'roughness_const_shin',
         'roughness_const_data', 'variable_roughness', 'free_stream_velocity',
         'free_stream_temp', 'characteristic_length', 'free_stream_temp_cp',
         'characteristic_length_cp', 'liquid_content', 'liquid_content_cp',
         'droplet_diameter', 'dpm_bc_type', 'dpm_bc_collision_partner',
         'reinj_inj', 'dpm_bc_norm_coeff', 'dpm_bc_tang_coeff',
         'dpm_bc_frictn_coeff', 'dpm_bc_udf', 'dpm_film_splash_nsamp',
         'dpm_crit_temp_option', 'dpm_critical_temp_factor',
         'dpm_calibratable_temp', 'dpm_impingement_splashing_model',
         'dpm_upper_deposition_limit_offset', 'dpm_deposition_delta_t',
         'dpm_laplace_number_constant', 'dpm_partial_evaporation_ratio',
         'ra_roughness', 'rz_roughness', 'rq_roughness', 'rsm_roughness',
         'dpm_bc_erosion_generic', 'dpm_bc_erosion', 'dpm_bc_erosion_c',
         'dpm_bc_erosion_n', 'dpm_bc_erosion_finnie',
         'dpm_bc_erosion_finnie_k', 'dpm_bc_erosion_finnie_vel_exp',
         'dpm_bc_erosion_finnie_max_erosion_angle', 'dpm_bc_erosion_mclaury',
         'dpm_bc_erosion_mclaury_a', 'dpm_bc_erosion_mclaury_vel_exp',
         'dpm_bc_erosion_mclaury_transition_angle',
         'dpm_bc_erosion_mclaury_b', 'dpm_bc_erosion_mclaury_c',
         'dpm_bc_erosion_mclaury_w', 'dpm_bc_erosion_mclaury_x',
         'dpm_bc_erosion_mclaury_y', 'dpm_bc_erosion_oka',
         'dpm_bc_erosion_oka_e90', 'dpm_bc_erosion_oka_hv',
         'dpm_bc_erosion_oka_n1', 'dpm_bc_erosion_oka_n2',
         'dpm_bc_erosion_oka_k2', 'dpm_bc_erosion_oka_k3',
         'dpm_bc_erosion_oka_dref', 'dpm_bc_erosion_oka_vref',
         'dpm_bc_erosion_dnv', 'dpm_bc_erosion_dnv_k', 'dpm_bc_erosion_dnv_n',
         'dpm_bc_erosion_dnv_ductile', 'dpm_bc_erosion_shear',
         'dpm_bc_erosion_shear_v', 'dpm_bc_erosion_shear_c',
         'dpm_bc_erosion_shear_packing_limit', 'dpm_bc_erosion_shielding',
         'dpm_wall_heat_exchange', 'dpm_film_condensation',
         'dpm_film_bl_model', 'dpm_particle_stripping',
         'dpm_critical_shear_stress', 'dpm_film_separation_model',
         'dpm_critical_we_number', 'dpm_film_separation_angle',
         'dpm_allow_lwf_to_vof', 'dpm_allow_vof_to_lwf', 'dpm_initialize_lwf',
         'dpm_initial_height', 'film_velocity', 'dpm_initial_temperature',
         'dpm_initial_injection', 'film_parcel_surface_area_density',
         'minimum_number_of_parcels_per_face', 'band_in_emiss',
         'radiation_bc', 'mc_bsource_p', 'mc_poldfun_p', 'polar_func_type',
         'mc_polar_expr', 'polar_pair_list', 'pold_pair_list_rad',
         'component_of_radiation_direction', 'coll_dtheta', 'coll_dphi',
         'band_q_irrad', 'band_q_irrad_diffuse', 'band_diffuse_frac',
         'radiating_s2s_surface', 'critical_zone', 'fpsc',
         'parallel_collimated_beam', 'solar_fluxes', 'solar_direction',
         'solar_irradiation', 'v_transmissivity', 'ir_transmissivity',
         'v_opq_absorbtivity', 'ir_opq_absorbtivity', 'v_st_absorbtivity',
         'ir_st_absorbtivity', 'd_st_absorbtivity', 'd_transmissivity',
         'fsi_interface', 'react', 'partially_catalytic',
         'partially_catalytic_material',
         'partially_catalytic_recombination_coefficient_o',
         'partially_catalytic_recombination_coefficient_n',
         'partially_catalytic_recombination_model', 'species_spec', 'mf',
         'elec_potential_type', 'potential_value', 'elec_potential_jump',
         'elec_potential_resistance', 'dual_potential_type',
         'dual_potential_value', 'echem_reaction', 'elec_potential_mechs',
         'faradaic_heat', 'li_ion_type', 'li_ion_value',
         'x_displacement_type', 'x_displacement_value', 'y_displacement_type',
         'y_displacement_value', 'z_displacement_type',
         'z_displacement_value', 'per_dispx', 'per_dispy', 'per_dispz',
         'per_imagx', 'per_imagy', 'per_imagz', 'freq', 'amp', 'nodal_diam',
         'pass_number', 'fwd', 'aero', 'cmplx', 'norm', 'method', 'uds_bc',
         'uds', 'gtemp_bc', 'g_temperature', 'g_qflux',
         'wall_restitution_coeff', 'omega',
         'origin_position_of_rotation_axis',
         'direction_component_of_rotation_axis', 'adhesion_angle',
         'specified_shear', 'shear_y', 'shear_z', 'shear_stress_components',
         'fslip', 'eslip', 'surf_tens_grad', 'contact_resistance',
         'reaction_mechs', 'surf_washcoat_factor', 'ablation_select_model',
         'ablation_vielle_a', 'ablation_vielle_n',
         'ablation_surfacerxn_density', 'ablation_flux',
         'ablation_species_mf', 'specular_coeff', 'mom_accom_coef',
         'therm_accom_coef', 'eve_accom_coef', 'film_wall', 'film_wall_bc',
         'film_height', 'flux_momentum_components', 'film_relative_vel',
         'film_bc_imp_press', 'film_temperature', 'film_scalar',
         'film_source', 'film_h_src', 'film_u_src', 'film_v_src',
         'film_w_src', 'momentum_source_components', 'film_t_src',
         'film_s_src', 'film_phase_change', 'film_phase_change_model',
         'film_cond_const', 'film_vapo_const', 'film_cond_rate',
         'film_vapo_rate', 'film_momentum_coupling', 'film_splash_wall',
         'film_boundary_separation', 'film_impinge_model',
         'film_splash_nparc', 'film_crit_temp_factor', 'film_roughness_ra',
         'film_roughness_rz', 'film_upper_deposition_limit_offset',
         'film_deposition_delta_t', 'film_laplace_number_constant',
         'film_partial_evap_ratio', 'film_contact_angle',
         'film_contact_angle_mean', 'film_contact_angle_rstd',
         'film_contact_angle_beta', 'film_vof_coupling_high',
         'film_vof_trans_high', 'film_vof_trans_high_relax',
         'film_vof_coupling_low', 'film_vof_trans_low',
         'film_vof_trans_low_relax', 'caf', 'thermal_stabilization',
         'scale_factor', 'stab_method', 'fensapice_ice_icing_mode',
         'fensapice_ice_hflux', 'fensapice_ice_hflux_1',
         'fensapice_drop_vwet']

    _child_classes = dict(
        geom_disable=geom_disable_cls,
        geom_dir_spec=geom_dir_spec_cls,
        geom_dir_x=geom_dir_x_cls,
        geom_dir_y=geom_dir_y_cls,
        geom_dir_z=geom_dir_z_cls,
        geom_levels=geom_levels_cls,
        geom_bgthread=geom_bgthread_cls,
        d=d_cls,
        q_dot=q_dot_cls,
        material=material_cls,
        thermal_bc=thermal_bc_cls,
        t=t_cls,
        q=q_cls,
        h=h_cls,
        tinf=tinf_cls,
        planar_conduction=planar_conduction_cls,
        shell_conduction=shell_conduction_cls,
        thin_wall=thin_wall_cls,
        motion_bc=motion_bc_cls,
        shear_bc=shear_bc_cls,
        rough_bc=rough_bc_cls,
        moving=moving_cls,
        relative=relative_cls,
        rotating=rotating_cls,
        vmag=vmag_cls,
        component_of_wall_translation=component_of_wall_translation_cls,
        components=components_cls,
        x_velocity=x_velocity_cls,
        y_velocity=y_velocity_cls,
        z_velocity=z_velocity_cls,
        velocity_components=velocity_components_cls,
        in_emiss=in_emiss_cls,
        ex_emiss=ex_emiss_cls,
        trad=trad_cls,
        int_rad=int_rad_cls,
        trad_internal=trad_internal_cls,
        area_enhancement_factor=area_enhancement_factor_cls,
        rough_option=rough_option_cls,
        rough_nasa=rough_nasa_cls,
        rough_shin_et_al=rough_shin_et_al_cls,
        rough_data=rough_data_cls,
        roughness_height=roughness_height_cls,
        roughness_const=roughness_const_cls,
        roughness_height_cp=roughness_height_cp_cls,
        roughness_const_cp=roughness_const_cp_cls,
        roughness_const_nasa=roughness_const_nasa_cls,
        roughness_const_shin=roughness_const_shin_cls,
        roughness_const_data=roughness_const_data_cls,
        variable_roughness=variable_roughness_cls,
        free_stream_velocity=free_stream_velocity_cls,
        free_stream_temp=free_stream_temp_cls,
        characteristic_length=characteristic_length_cls,
        free_stream_temp_cp=free_stream_temp_cp_cls,
        characteristic_length_cp=characteristic_length_cp_cls,
        liquid_content=liquid_content_cls,
        liquid_content_cp=liquid_content_cp_cls,
        droplet_diameter=droplet_diameter_cls,
        dpm_bc_type=dpm_bc_type_cls,
        dpm_bc_collision_partner=dpm_bc_collision_partner_cls,
        reinj_inj=reinj_inj_cls,
        dpm_bc_norm_coeff=dpm_bc_norm_coeff_cls,
        dpm_bc_tang_coeff=dpm_bc_tang_coeff_cls,
        dpm_bc_frictn_coeff=dpm_bc_frictn_coeff_cls,
        dpm_bc_udf=dpm_bc_udf_cls,
        dpm_film_splash_nsamp=dpm_film_splash_nsamp_cls,
        dpm_crit_temp_option=dpm_crit_temp_option_cls,
        dpm_critical_temp_factor=dpm_critical_temp_factor_cls,
        dpm_calibratable_temp=dpm_calibratable_temp_cls,
        dpm_impingement_splashing_model=dpm_impingement_splashing_model_cls,
        dpm_upper_deposition_limit_offset=dpm_upper_deposition_limit_offset_cls,
        dpm_deposition_delta_t=dpm_deposition_delta_t_cls,
        dpm_laplace_number_constant=dpm_laplace_number_constant_cls,
        dpm_partial_evaporation_ratio=dpm_partial_evaporation_ratio_cls,
        ra_roughness=ra_roughness_cls,
        rz_roughness=rz_roughness_cls,
        rq_roughness=rq_roughness_cls,
        rsm_roughness=rsm_roughness_cls,
        dpm_bc_erosion_generic=dpm_bc_erosion_generic_cls,
        dpm_bc_erosion=dpm_bc_erosion_cls,
        dpm_bc_erosion_c=dpm_bc_erosion_c_cls,
        dpm_bc_erosion_n=dpm_bc_erosion_n_cls,
        dpm_bc_erosion_finnie=dpm_bc_erosion_finnie_cls,
        dpm_bc_erosion_finnie_k=dpm_bc_erosion_finnie_k_cls,
        dpm_bc_erosion_finnie_vel_exp=dpm_bc_erosion_finnie_vel_exp_cls,
        dpm_bc_erosion_finnie_max_erosion_angle=dpm_bc_erosion_finnie_max_erosion_angle_cls,
        dpm_bc_erosion_mclaury=dpm_bc_erosion_mclaury_cls,
        dpm_bc_erosion_mclaury_a=dpm_bc_erosion_mclaury_a_cls,
        dpm_bc_erosion_mclaury_vel_exp=dpm_bc_erosion_mclaury_vel_exp_cls,
        dpm_bc_erosion_mclaury_transition_angle=dpm_bc_erosion_mclaury_transition_angle_cls,
        dpm_bc_erosion_mclaury_b=dpm_bc_erosion_mclaury_b_cls,
        dpm_bc_erosion_mclaury_c=dpm_bc_erosion_mclaury_c_cls,
        dpm_bc_erosion_mclaury_w=dpm_bc_erosion_mclaury_w_cls,
        dpm_bc_erosion_mclaury_x=dpm_bc_erosion_mclaury_x_cls,
        dpm_bc_erosion_mclaury_y=dpm_bc_erosion_mclaury_y_cls,
        dpm_bc_erosion_oka=dpm_bc_erosion_oka_cls,
        dpm_bc_erosion_oka_e90=dpm_bc_erosion_oka_e90_cls,
        dpm_bc_erosion_oka_hv=dpm_bc_erosion_oka_hv_cls,
        dpm_bc_erosion_oka_n1=dpm_bc_erosion_oka_n1_cls,
        dpm_bc_erosion_oka_n2=dpm_bc_erosion_oka_n2_cls,
        dpm_bc_erosion_oka_k2=dpm_bc_erosion_oka_k2_cls,
        dpm_bc_erosion_oka_k3=dpm_bc_erosion_oka_k3_cls,
        dpm_bc_erosion_oka_dref=dpm_bc_erosion_oka_dref_cls,
        dpm_bc_erosion_oka_vref=dpm_bc_erosion_oka_vref_cls,
        dpm_bc_erosion_dnv=dpm_bc_erosion_dnv_cls,
        dpm_bc_erosion_dnv_k=dpm_bc_erosion_dnv_k_cls,
        dpm_bc_erosion_dnv_n=dpm_bc_erosion_dnv_n_cls,
        dpm_bc_erosion_dnv_ductile=dpm_bc_erosion_dnv_ductile_cls,
        dpm_bc_erosion_shear=dpm_bc_erosion_shear_cls,
        dpm_bc_erosion_shear_v=dpm_bc_erosion_shear_v_cls,
        dpm_bc_erosion_shear_c=dpm_bc_erosion_shear_c_cls,
        dpm_bc_erosion_shear_packing_limit=dpm_bc_erosion_shear_packing_limit_cls,
        dpm_bc_erosion_shielding=dpm_bc_erosion_shielding_cls,
        dpm_wall_heat_exchange=dpm_wall_heat_exchange_cls,
        dpm_film_condensation=dpm_film_condensation_cls,
        dpm_film_bl_model=dpm_film_bl_model_cls,
        dpm_particle_stripping=dpm_particle_stripping_cls,
        dpm_critical_shear_stress=dpm_critical_shear_stress_cls,
        dpm_film_separation_model=dpm_film_separation_model_cls,
        dpm_critical_we_number=dpm_critical_we_number_cls,
        dpm_film_separation_angle=dpm_film_separation_angle_cls,
        dpm_allow_lwf_to_vof=dpm_allow_lwf_to_vof_cls,
        dpm_allow_vof_to_lwf=dpm_allow_vof_to_lwf_cls,
        dpm_initialize_lwf=dpm_initialize_lwf_cls,
        dpm_initial_height=dpm_initial_height_cls,
        film_velocity=film_velocity_cls,
        dpm_initial_temperature=dpm_initial_temperature_cls,
        dpm_initial_injection=dpm_initial_injection_cls,
        film_parcel_surface_area_density=film_parcel_surface_area_density_cls,
        minimum_number_of_parcels_per_face=minimum_number_of_parcels_per_face_cls,
        band_in_emiss=band_in_emiss_cls,
        radiation_bc=radiation_bc_cls,
        mc_bsource_p=mc_bsource_p_cls,
        mc_poldfun_p=mc_poldfun_p_cls,
        polar_func_type=polar_func_type_cls,
        mc_polar_expr=mc_polar_expr_cls,
        polar_pair_list=polar_pair_list_cls,
        pold_pair_list_rad=pold_pair_list_rad_cls,
        component_of_radiation_direction=component_of_radiation_direction_cls,
        coll_dtheta=coll_dtheta_cls,
        coll_dphi=coll_dphi_cls,
        band_q_irrad=band_q_irrad_cls,
        band_q_irrad_diffuse=band_q_irrad_diffuse_cls,
        band_diffuse_frac=band_diffuse_frac_cls,
        radiating_s2s_surface=radiating_s2s_surface_cls,
        critical_zone=critical_zone_cls,
        fpsc=fpsc_cls,
        parallel_collimated_beam=parallel_collimated_beam_cls,
        solar_fluxes=solar_fluxes_cls,
        solar_direction=solar_direction_cls,
        solar_irradiation=solar_irradiation_cls,
        v_transmissivity=v_transmissivity_cls,
        ir_transmissivity=ir_transmissivity_cls,
        v_opq_absorbtivity=v_opq_absorbtivity_cls,
        ir_opq_absorbtivity=ir_opq_absorbtivity_cls,
        v_st_absorbtivity=v_st_absorbtivity_cls,
        ir_st_absorbtivity=ir_st_absorbtivity_cls,
        d_st_absorbtivity=d_st_absorbtivity_cls,
        d_transmissivity=d_transmissivity_cls,
        fsi_interface=fsi_interface_cls,
        react=react_cls,
        partially_catalytic=partially_catalytic_cls,
        partially_catalytic_material=partially_catalytic_material_cls,
        partially_catalytic_recombination_coefficient_o=partially_catalytic_recombination_coefficient_o_cls,
        partially_catalytic_recombination_coefficient_n=partially_catalytic_recombination_coefficient_n_cls,
        partially_catalytic_recombination_model=partially_catalytic_recombination_model_cls,
        species_spec=species_spec_cls,
        mf=mf_cls,
        elec_potential_type=elec_potential_type_cls,
        potential_value=potential_value_cls,
        elec_potential_jump=elec_potential_jump_cls,
        elec_potential_resistance=elec_potential_resistance_cls,
        dual_potential_type=dual_potential_type_cls,
        dual_potential_value=dual_potential_value_cls,
        echem_reaction=echem_reaction_cls,
        elec_potential_mechs=elec_potential_mechs_cls,
        faradaic_heat=faradaic_heat_cls,
        li_ion_type=li_ion_type_cls,
        li_ion_value=li_ion_value_cls,
        x_displacement_type=x_displacement_type_cls,
        x_displacement_value=x_displacement_value_cls,
        y_displacement_type=y_displacement_type_cls,
        y_displacement_value=y_displacement_value_cls,
        z_displacement_type=z_displacement_type_cls,
        z_displacement_value=z_displacement_value_cls,
        per_dispx=per_dispx_cls,
        per_dispy=per_dispy_cls,
        per_dispz=per_dispz_cls,
        per_imagx=per_imagx_cls,
        per_imagy=per_imagy_cls,
        per_imagz=per_imagz_cls,
        freq=freq_cls,
        amp=amp_cls,
        nodal_diam=nodal_diam_cls,
        pass_number=pass_number_cls,
        fwd=fwd_cls,
        aero=aero_cls,
        cmplx=cmplx_cls,
        norm=norm_cls,
        method=method_cls,
        uds_bc=uds_bc_cls,
        uds=uds_cls,
        gtemp_bc=gtemp_bc_cls,
        g_temperature=g_temperature_cls,
        g_qflux=g_qflux_cls,
        wall_restitution_coeff=wall_restitution_coeff_cls,
        omega=omega_cls,
        origin_position_of_rotation_axis=origin_position_of_rotation_axis_cls,
        direction_component_of_rotation_axis=direction_component_of_rotation_axis_cls,
        adhesion_angle=adhesion_angle_cls,
        specified_shear=specified_shear_cls,
        shear_y=shear_y_cls,
        shear_z=shear_z_cls,
        shear_stress_components=shear_stress_components_cls,
        fslip=fslip_cls,
        eslip=eslip_cls,
        surf_tens_grad=surf_tens_grad_cls,
        contact_resistance=contact_resistance_cls,
        reaction_mechs=reaction_mechs_cls,
        surf_washcoat_factor=surf_washcoat_factor_cls,
        ablation_select_model=ablation_select_model_cls,
        ablation_vielle_a=ablation_vielle_a_cls,
        ablation_vielle_n=ablation_vielle_n_cls,
        ablation_surfacerxn_density=ablation_surfacerxn_density_cls,
        ablation_flux=ablation_flux_cls,
        ablation_species_mf=ablation_species_mf_cls,
        specular_coeff=specular_coeff_cls,
        mom_accom_coef=mom_accom_coef_cls,
        therm_accom_coef=therm_accom_coef_cls,
        eve_accom_coef=eve_accom_coef_cls,
        film_wall=film_wall_cls,
        film_wall_bc=film_wall_bc_cls,
        film_height=film_height_cls,
        flux_momentum_components=flux_momentum_components_cls,
        film_relative_vel=film_relative_vel_cls,
        film_bc_imp_press=film_bc_imp_press_cls,
        film_temperature=film_temperature_cls,
        film_scalar=film_scalar_cls,
        film_source=film_source_cls,
        film_h_src=film_h_src_cls,
        film_u_src=film_u_src_cls,
        film_v_src=film_v_src_cls,
        film_w_src=film_w_src_cls,
        momentum_source_components=momentum_source_components_cls,
        film_t_src=film_t_src_cls,
        film_s_src=film_s_src_cls,
        film_phase_change=film_phase_change_cls,
        film_phase_change_model=film_phase_change_model_cls,
        film_cond_const=film_cond_const_cls,
        film_vapo_const=film_vapo_const_cls,
        film_cond_rate=film_cond_rate_cls,
        film_vapo_rate=film_vapo_rate_cls,
        film_momentum_coupling=film_momentum_coupling_cls,
        film_splash_wall=film_splash_wall_cls,
        film_boundary_separation=film_boundary_separation_cls,
        film_impinge_model=film_impinge_model_cls,
        film_splash_nparc=film_splash_nparc_cls,
        film_crit_temp_factor=film_crit_temp_factor_cls,
        film_roughness_ra=film_roughness_ra_cls,
        film_roughness_rz=film_roughness_rz_cls,
        film_upper_deposition_limit_offset=film_upper_deposition_limit_offset_cls,
        film_deposition_delta_t=film_deposition_delta_t_cls,
        film_laplace_number_constant=film_laplace_number_constant_cls,
        film_partial_evap_ratio=film_partial_evap_ratio_cls,
        film_contact_angle=film_contact_angle_cls,
        film_contact_angle_mean=film_contact_angle_mean_cls,
        film_contact_angle_rstd=film_contact_angle_rstd_cls,
        film_contact_angle_beta=film_contact_angle_beta_cls,
        film_vof_coupling_high=film_vof_coupling_high_cls,
        film_vof_trans_high=film_vof_trans_high_cls,
        film_vof_trans_high_relax=film_vof_trans_high_relax_cls,
        film_vof_coupling_low=film_vof_coupling_low_cls,
        film_vof_trans_low=film_vof_trans_low_cls,
        film_vof_trans_low_relax=film_vof_trans_low_relax_cls,
        caf=caf_cls,
        thermal_stabilization=thermal_stabilization_cls,
        scale_factor=scale_factor_cls,
        stab_method=stab_method_cls,
        fensapice_ice_icing_mode=fensapice_ice_icing_mode_cls,
        fensapice_ice_hflux=fensapice_ice_hflux_cls,
        fensapice_ice_hflux_1=fensapice_ice_hflux_1_cls,
        fensapice_drop_vwet=fensapice_drop_vwet_cls,
    )

    return_type = "<object object at 0x7fd82af54310>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .adaptive_time_stepping import adaptive_time_stepping as adaptive_time_stepping_cls
from .cfl_based_adaptive_time_stepping import cfl_based_adaptive_time_stepping as cfl_based_adaptive_time_stepping_cls
from .data_sampling_1 import data_sampling as data_sampling_cls
from .transient_controls import transient_controls as transient_controls_cls
from .dual_time_iterate import dual_time_iterate as dual_time_iterate_cls
from .iterate import iterate as iterate_cls

class run_calculation(Group):
    """
    'run_calculation' child.
    """

    fluent_name = "run-calculation"

    child_names = \
        ['adaptive_time_stepping', 'cfl_based_adaptive_time_stepping',
         'data_sampling', 'transient_controls']

    command_names = \
        ['dual_time_iterate', 'iterate']

    _child_classes = dict(
        adaptive_time_stepping=adaptive_time_stepping_cls,
        cfl_based_adaptive_time_stepping=cfl_based_adaptive_time_stepping_cls,
        data_sampling=data_sampling_cls,
        transient_controls=transient_controls_cls,
        dual_time_iterate=dual_time_iterate_cls,
        iterate=iterate_cls,
    )

    return_type = "<object object at 0x7fd82ae3b070>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .histogram import histogram as histogram_cls
from .sample_trajectories import sample_trajectories as sample_trajectories_cls
from .summary import summary as summary_cls
from .extended_summary import extended_summary as extended_summary_cls
from .zone_summaries_per_injection import zone_summaries_per_injection as zone_summaries_per_injection_cls

class discrete_phase(Group):
    fluent_name = ...
    child_names = ...
    histogram: histogram_cls = ...
    sample_trajectories: sample_trajectories_cls = ...
    command_names = ...

    def summary(self, ):
        """
        Print discrete phase summary report of particle fates.
        """

    def extended_summary(self, write_summary_to_file: bool, file_name: str, include_in_domains_particles: bool, pick_injection: bool, injection: str):
        """
        Print extended discrete phase summary report of particle fates, with options.
        
        Parameters
        ----------
            write_summary_to_file : bool
                'write_summary_to_file' child.
            file_name : str
                'file_name' child.
            include_in_domains_particles : bool
                'include_in_domains_particles' child.
            pick_injection : bool
                'pick_injection' child.
            injection : str
                'injection' child.
        
        """

    def zone_summaries_per_injection(self, summary_state: bool, reset_dpm_summaries: bool):
        """
        Enable per-injection zone DPM summaries.
        
        Parameters
        ----------
            summary_state : bool
                'summary_state' child.
            reset_dpm_summaries : bool
                'reset_dpm_summaries' child.
        
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .solver import solver as solver_cls
from .adjust_solver_defaults_based_on_setup import adjust_solver_defaults_based_on_setup as adjust_solver_defaults_based_on_setup_cls
from .gravity import gravity as gravity_cls

class general(Group):
    fluent_name = ...
    child_names = ...
    solver: solver_cls = ...
    adjust_solver_defaults_based_on_setup: adjust_solver_defaults_based_on_setup_cls = ...
    gravity: gravity_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .allow_repair_at_boundaries import allow_repair_at_boundaries as allow_repair_at_boundaries_cls
from .include_local_polyhedra_conversion_in_repair import include_local_polyhedra_conversion_in_repair as include_local_polyhedra_conversion_in_repair_cls
from .repair_poor_elements import repair_poor_elements as repair_poor_elements_cls
from .improve_quality import improve_quality as improve_quality_cls
from .repair import repair as repair_cls
from .repair_face_handedness import repair_face_handedness as repair_face_handedness_cls
from .repair_face_node_order import repair_face_node_order as repair_face_node_order_cls
from .repair_wall_distance import repair_wall_distance as repair_wall_distance_cls

class repair_improve(Group):
    """
    Enter the repair and improve quality menu.
    """

    fluent_name = "repair-improve"

    child_names = \
        ['allow_repair_at_boundaries',
         'include_local_polyhedra_conversion_in_repair']

    command_names = \
        ['repair_poor_elements', 'improve_quality', 'repair',
         'repair_face_handedness', 'repair_face_node_order',
         'repair_wall_distance']

    _child_classes = dict(
        allow_repair_at_boundaries=allow_repair_at_boundaries_cls,
        include_local_polyhedra_conversion_in_repair=include_local_polyhedra_conversion_in_repair_cls,
        repair_poor_elements=repair_poor_elements_cls,
        improve_quality=improve_quality_cls,
        repair=repair_cls,
        repair_face_handedness=repair_face_handedness_cls,
        repair_face_node_order=repair_face_node_order_cls,
        repair_wall_distance=repair_wall_distance_cls,
    )

    return_type = "<object object at 0x7fc5c18a7960>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option_8 import option as option_cls
from .virtual_mass_factor import virtual_mass_factor as virtual_mass_factor_cls

class virtual_mass_force(Group):
    """
    'virtual_mass_force' child.
    """

    fluent_name = "virtual-mass-force"

    child_names = \
        ['option', 'virtual_mass_factor']

    _child_classes = dict(
        option=option_cls,
        virtual_mass_factor=virtual_mass_factor_cls,
    )

    return_type = "<object object at 0x7fb66c2e14d0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .components_2 import components as components_cls
from .list_properties_4 import list_properties as list_properties_cls

class groups_child(Group):
    """
    'child_object_type' of groups.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['components']

    command_names = \
        ['list_properties']

    _child_classes = dict(
        components=components_cls,
        list_properties=list_properties_cls,
    )

    return_type = "<object object at 0x7fb5f629a6d0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .buoyancy_force_linearization import buoyancy_force_linearization as buoyancy_force_linearization_cls
from .blended_treatment_for_buoyancy_forces import blended_treatment_for_buoyancy_forces as blended_treatment_for_buoyancy_forces_cls

class coupled_vof(Group):
    fluent_name = ...
    child_names = ...
    buoyancy_force_linearization: buoyancy_force_linearization_cls = ...
    blended_treatment_for_buoyancy_forces: blended_treatment_for_buoyancy_forces_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .file_type import file_type as file_type_cls
from .file_name_1 import file_name as file_name_cls
from .pdf_file_name import pdf_file_name as pdf_file_name_cls
from .lightweight_setup import lightweight_setup as lightweight_setup_cls

class read_case_data(Command):
    fluent_name = ...
    argument_names = ...
    file_type: file_type_cls = ...
    file_name: file_name_cls = ...
    pdf_file_name: pdf_file_name_cls = ...
    lightweight_setup: lightweight_setup_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .iter_count_4 import iter_count as iter_count_cls
from .time_steps_count import time_steps_count as time_steps_count_cls
from .fluid_time_step_count import fluid_time_step_count as fluid_time_step_count_cls
from .iter_per_time_step_count import iter_per_time_step_count as iter_per_time_step_count_cls

class dual_time_iterate(Command):
    """
    Dual-time iterate the multidomain conjugate heat transfer.
    
    Parameters
    ----------
        iter_count : int
            'iter_count' child.
        time_steps_count : int
            'time_steps_count' child.
        fluid_time_step_count : int
            'fluid_time_step_count' child.
        iter_per_time_step_count : int
            'iter_per_time_step_count' child.
    
    """

    fluent_name = "dual-time-iterate"

    argument_names = \
        ['iter_count', 'time_steps_count', 'fluid_time_step_count',
         'iter_per_time_step_count']

    _child_classes = dict(
        iter_count=iter_count_cls,
        time_steps_count=time_steps_count_cls,
        fluid_time_step_count=fluid_time_step_count_cls,
        iter_per_time_step_count=iter_per_time_step_count_cls,
    )

    return_type = "<object object at 0x7fb5f5e785e0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .width import width as width_cls
from .height import height as height_cls

class field(Command):
    """
    Set the field of view (width and height).
    
    Parameters
    ----------
        width : real
            'width' child.
        height : real
            'height' child.
    
    """

    fluent_name = "field"

    argument_names = \
        ['width', 'height']

    _child_classes = dict(
        width=width_cls,
        height=height_cls,
    )

    return_type = "<object object at 0x7fc55413e230>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .initial_time_steps import initial_time_steps as initial_time_steps_cls
from .initial_outer_iter import initial_outer_iter as initial_outer_iter_cls

class initial_outer_iterations(Group):
    """
    'initial_outer_iterations' child.
    """

    fluent_name = "initial-outer-iterations"

    child_names = \
        ['initial_time_steps', 'initial_outer_iter']

    _child_classes = dict(
        initial_time_steps=initial_time_steps_cls,
        initial_outer_iter=initial_outer_iter_cls,
    )

    return_type = "<object object at 0x7fd82ae39610>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .option_3 import option as option_cls
from .consistency_index import consistency_index as consistency_index_cls
from .power_law_index import power_law_index as power_law_index_cls
from .yield_stress_threshold import yield_stress_threshold as yield_stress_threshold_cls
from .critical_shear_rate import critical_shear_rate as critical_shear_rate_cls
from .reference_temperature import reference_temperature as reference_temperature_cls
from .activation_energy import activation_energy as activation_energy_cls

class herschel_bulkley(Group):
    fluent_name = ...
    child_names = ...
    option: option_cls = ...
    consistency_index: consistency_index_cls = ...
    power_law_index: power_law_index_cls = ...
    yield_stress_threshold: yield_stress_threshold_cls = ...
    critical_shear_rate: critical_shear_rate_cls = ...
    reference_temperature: reference_temperature_cls = ...
    activation_energy: activation_energy_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .style import style as style_cls
from .vector_length import vector_length as vector_length_cls
from .constant_color import constant_color as constant_color_cls
from .vector_of import vector_of as vector_of_cls
from .scale_1 import scale as scale_cls
from .length_to_head_ratio import length_to_head_ratio as length_to_head_ratio_cls

class vector_settings(Group):
    fluent_name = ...
    child_names = ...
    style: style_cls = ...
    vector_length: vector_length_cls = ...
    constant_color: constant_color_cls = ...
    vector_of: vector_of_cls = ...
    scale: scale_cls = ...
    length_to_head_ratio: length_to_head_ratio_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .smoothed_density_stabilization_method import smoothed_density_stabilization_method as smoothed_density_stabilization_method_cls
from .num_of_density_smoothing import num_of_density_smoothing as num_of_density_smoothing_cls
from .false_time_step_linearization import false_time_step_linearization as false_time_step_linearization_cls
from .auto_dt_advanced_controls import auto_dt_advanced_controls as auto_dt_advanced_controls_cls

class pseudo_transient(Group):
    """
    Pseudo-Time stability controls for multiphase flow.
    """

    fluent_name = "pseudo-transient"

    child_names = \
        ['smoothed_density_stabilization_method', 'num_of_density_smoothing',
         'false_time_step_linearization', 'auto_dt_advanced_controls']

    _child_classes = dict(
        smoothed_density_stabilization_method=smoothed_density_stabilization_method_cls,
        num_of_density_smoothing=num_of_density_smoothing_cls,
        false_time_step_linearization=false_time_step_linearization_cls,
        auto_dt_advanced_controls=auto_dt_advanced_controls_cls,
    )

    return_type = "<object object at 0x7fc55434fe20>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .pre_sweeps_1 import pre_sweeps as pre_sweeps_cls
from .post_sweeps_1 import post_sweeps as post_sweeps_cls
from .max_cycle_1 import max_cycle as max_cycle_cls

class fixed_cycle_parameters(Group):
    """
    'fixed_cycle_parameters' child.
    """

    fluent_name = "fixed-cycle-parameters"

    child_names = \
        ['pre_sweeps', 'post_sweeps', 'max_cycle']

    _child_classes = dict(
        pre_sweeps=pre_sweeps_cls,
        post_sweeps=post_sweeps_cls,
        max_cycle=max_cycle_cls,
    )

    return_type = "<object object at 0x7fc55434ed80>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .x_component import x_component as x_component_cls
from .y_component import y_component as y_component_cls
from .z_component import z_component as z_component_cls

class direction_vector(Group):
    """
    'direction_vector' child.
    """

    fluent_name = "direction-vector"

    child_names = \
        ['x_component', 'y_component', 'z_component']

    _child_classes = dict(
        x_component=x_component_cls,
        y_component=y_component_cls,
        z_component=z_component_cls,
    )

    return_type = "<object object at 0x7fb5f5f71680>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .name import name as name_cls
from .surface_name_list_1 import surface_name_list as surface_name_list_cls
from .delimiter import delimiter as delimiter_cls
from .cell_func_domain import cell_func_domain as cell_func_domain_cls
from .location import location as location_cls

class ascii(Command):
    """
    Write an ASCII file.
    
    Parameters
    ----------
        name : str
            'name' child.
        surface_name_list : List
            List of surfaces to export.
        delimiter : str
            'delimiter' child.
        cell_func_domain : List
            'cell_func_domain' child.
        location : str
            'location' child.
    
    """

    fluent_name = "ascii"

    argument_names = \
        ['name', 'surface_name_list', 'delimiter', 'cell_func_domain',
         'location']

    _child_classes = dict(
        name=name_cls,
        surface_name_list=surface_name_list_cls,
        delimiter=delimiter_cls,
        cell_func_domain=cell_func_domain_cls,
        location=location_cls,
    )

    return_type = "<object object at 0x7fb6784da900>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .error_tolerance_1 import error_tolerance as error_tolerance_cls
from .initial_time_step_size import initial_time_step_size as initial_time_step_size_cls
from .fixed_time_step_size import fixed_time_step_size as fixed_time_step_size_cls
from .min_time_step_size import min_time_step_size as min_time_step_size_cls
from .max_time_step_size import max_time_step_size as max_time_step_size_cls
from .min_step_change_factor import min_step_change_factor as min_step_change_factor_cls
from .max_step_change_factor import max_step_change_factor as max_step_change_factor_cls
from .update_interval import update_interval as update_interval_cls

class error_based_time_stepping(Group):
    fluent_name = ...
    child_names = ...
    error_tolerance: error_tolerance_cls = ...
    initial_time_step_size: initial_time_step_size_cls = ...
    fixed_time_step_size: fixed_time_step_size_cls = ...
    min_time_step_size: min_time_step_size_cls = ...
    max_time_step_size: max_time_step_size_cls = ...
    min_step_change_factor: min_step_change_factor_cls = ...
    max_step_change_factor: max_step_change_factor_cls = ...
    update_interval: update_interval_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .auto_scale_2 import auto_scale as auto_scale_cls
from .clip_to_range_2 import clip_to_range as clip_to_range_cls
from .surfaces_1 import surfaces as surfaces_cls
from .filled_contours import filled_contours as filled_contours_cls
from .global_range_1 import global_range as global_range_cls
from .line_contours import line_contours as line_contours_cls
from .log_scale_2 import log_scale as log_scale_cls
from .n_contour import n_contour as n_contour_cls
from .node_values_2 import node_values as node_values_cls
from .render_mesh import render_mesh as render_mesh_cls
from .coloring_2 import coloring as coloring_cls

class contours(Group):
    fluent_name = ...
    child_names = ...
    auto_scale: auto_scale_cls = ...
    clip_to_range: clip_to_range_cls = ...
    surfaces: surfaces_cls = ...
    filled_contours: filled_contours_cls = ...
    global_range: global_range_cls = ...
    line_contours: line_contours_cls = ...
    log_scale: log_scale_cls = ...
    n_contour: n_contour_cls = ...
    node_values: node_values_cls = ...
    render_mesh: render_mesh_cls = ...
    coloring: coloring_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .type import type as type_cls
from .two_dim_space import two_dim_space as two_dim_space_cls
from .velocity_formulation import velocity_formulation as velocity_formulation_cls
from .time import time as time_cls

class solver(Group):
    fluent_name = ...
    child_names = ...
    type: type_cls = ...
    two_dim_space: two_dim_space_cls = ...
    velocity_formulation: velocity_formulation_cls = ...
    time: time_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .day import day as day_cls
from .month import month as month_cls
from .hour import hour as hour_cls
from .minute import minute as minute_cls

class date_and_time(Group):
    fluent_name = ...
    child_names = ...
    day: day_cls = ...
    month: month_cls = ...
    hour: hour_cls = ...
    minute: minute_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .setting_type import setting_type as setting_type_cls

class modified_setting(Command):
    """
    Specify which settings will be checked for non-default status for generating the Modified Settings Summary table.
    
    Parameters
    ----------
        setting_type : List
            'setting_type' child.
    
    """

    fluent_name = "modified-setting"

    argument_names = \
        ['setting_type']

    _child_classes = dict(
        setting_type=setting_type_cls,
    )

    return_type = "<object object at 0x7fb5f5f72e10>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .list import list as list_cls
from .list_properties import list_properties as list_properties_cls
from .duplicate import duplicate as duplicate_cls
from .species_child import species_child


class species(NamedObject[species_child], _NonCreatableNamedObjectMixin[species_child]):
    fluent_name = ...
    command_names = ...

    def list(self, ):
        """
        'list' command.
        """

    def list_properties(self, object_name: str):
        """
        'list_properties' command.
        
        Parameters
        ----------
            object_name : str
                'object_name' child.
        
        """

    def duplicate(self, from_: str, to: str):
        """
        'duplicate' command.
        
        Parameters
        ----------
            from_ : str
                'from' child.
            to : str
                'to' child.
        
        """

    child_object_type: species_child = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .local_dt_dualts_relax import local_dt_dualts_relax as local_dt_dualts_relax_cls
from .global_dt_pseudo_relax import global_dt_pseudo_relax as global_dt_pseudo_relax_cls

class relaxation_factors(Group):
    fluent_name = ...
    child_names = ...
    local_dt_dualts_relax: local_dt_dualts_relax_cls = ...
    global_dt_pseudo_relax: global_dt_pseudo_relax_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .n_theta_divisions import n_theta_divisions as n_theta_divisions_cls
from .n_phi_divisions import n_phi_divisions as n_phi_divisions_cls
from .n_theta_pixels import n_theta_pixels as n_theta_pixels_cls
from .n_phi_pixels import n_phi_pixels as n_phi_pixels_cls
from .do_acceleration import do_acceleration as do_acceleration_cls
from .do_energy_coupling import do_energy_coupling as do_energy_coupling_cls
from .method_partially_specular_wall import method_partially_specular_wall as method_partially_specular_wall_cls
from .fast_second_order_discrete_ordinate import fast_second_order_discrete_ordinate as fast_second_order_discrete_ordinate_cls
from .blending_factor import blending_factor as blending_factor_cls

class discrete_ordinates(Group):
    fluent_name = ...
    child_names = ...
    n_theta_divisions: n_theta_divisions_cls = ...
    n_phi_divisions: n_phi_divisions_cls = ...
    n_theta_pixels: n_theta_pixels_cls = ...
    n_phi_pixels: n_phi_pixels_cls = ...
    do_acceleration: do_acceleration_cls = ...
    do_energy_coupling: do_energy_coupling_cls = ...
    method_partially_specular_wall: method_partially_specular_wall_cls = ...
    fast_second_order_discrete_ordinate: fast_second_order_discrete_ordinate_cls = ...
    blending_factor: blending_factor_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .x_scale import x_scale as x_scale_cls
from .y_scale import y_scale as y_scale_cls
from .z_scale import z_scale as z_scale_cls

class scale(Command):
    """
    'scale' command.
    
    Parameters
    ----------
        x_scale : real
            'x_scale' child.
        y_scale : real
            'y_scale' child.
        z_scale : real
            'z_scale' child.
    
    """

    fluent_name = "scale"

    argument_names = \
        ['x_scale', 'y_scale', 'z_scale']

    _child_classes = dict(
        x_scale=x_scale_cls,
        y_scale=y_scale_cls,
        z_scale=z_scale_cls,
    )

    return_type = "<object object at 0x7fc5c18a7720>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option import option as option_cls
from .time_constant import time_constant as time_constant_cls
from .power_law_index import power_law_index as power_law_index_cls
from .zero_shear_viscosity import zero_shear_viscosity as zero_shear_viscosity_cls
from .infinite_shear_viscosity import infinite_shear_viscosity as infinite_shear_viscosity_cls
from .reference_temperature import reference_temperature as reference_temperature_cls
from .activation_energy import activation_energy as activation_energy_cls

class carreau(Group):
    """
    'carreau' child.
    """

    fluent_name = "carreau"

    child_names = \
        ['option', 'time_constant', 'power_law_index', 'zero_shear_viscosity',
         'infinite_shear_viscosity', 'reference_temperature',
         'activation_energy']

    _child_classes = dict(
        option=option_cls,
        time_constant=time_constant_cls,
        power_law_index=power_law_index_cls,
        zero_shear_viscosity=zero_shear_viscosity_cls,
        infinite_shear_viscosity=infinite_shear_viscosity_cls,
        reference_temperature=reference_temperature_cls,
        activation_energy=activation_energy_cls,
    )

    return_type = "<object object at 0x7fb66c2e2a40>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .error_tolerance_1 import error_tolerance as error_tolerance_cls
from .initial_time_step_size import initial_time_step_size as initial_time_step_size_cls
from .fixed_time_step_size import fixed_time_step_size as fixed_time_step_size_cls
from .min_time_step_size import min_time_step_size as min_time_step_size_cls
from .max_time_step_size import max_time_step_size as max_time_step_size_cls
from .min_step_change_factor import min_step_change_factor as min_step_change_factor_cls
from .max_step_change_factor import max_step_change_factor as max_step_change_factor_cls
from .update_interval import update_interval as update_interval_cls

class error_based_time_stepping(Group):
    """
    'error_based_time_stepping' child.
    """

    fluent_name = "error-based-time-stepping"

    child_names = \
        ['error_tolerance', 'initial_time_step_size', 'fixed_time_step_size',
         'min_time_step_size', 'max_time_step_size', 'min_step_change_factor',
         'max_step_change_factor', 'update_interval']

    _child_classes = dict(
        error_tolerance=error_tolerance_cls,
        initial_time_step_size=initial_time_step_size_cls,
        fixed_time_step_size=fixed_time_step_size_cls,
        min_time_step_size=min_time_step_size_cls,
        max_time_step_size=max_time_step_size_cls,
        min_step_change_factor=min_step_change_factor_cls,
        max_step_change_factor=max_step_change_factor_cls,
        update_interval=update_interval_cls,
    )

    return_type = "<object object at 0x7fc554242c50>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .dbns_cases import dbns_cases as dbns_cases_cls
from .pbns_cases import pbns_cases as pbns_cases_cls

class flux_type(Group):
    """
    Enter the flux type.
    """

    fluent_name = "flux-type"

    child_names = \
        ['dbns_cases', 'pbns_cases']

    _child_classes = dict(
        dbns_cases=dbns_cases_cls,
        pbns_cases=pbns_cases_cls,
    )

    return_type = "<object object at 0x7fc55434f9f0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .subgrid_scale_turb_visc import subgrid_scale_turb_visc as subgrid_scale_turb_visc_cls
from .turb_visc_func_mf import turb_visc_func_mf as turb_visc_func_mf_cls
from .turb_visc_func import turb_visc_func as turb_visc_func_cls
from .tke_prandtl import tke_prandtl as tke_prandtl_cls
from .tdr_prandtl import tdr_prandtl as tdr_prandtl_cls
from .sdr_prandtl import sdr_prandtl as sdr_prandtl_cls
from .energy_prandtl import energy_prandtl as energy_prandtl_cls
from .wall_prandtl import wall_prandtl as wall_prandtl_cls
from .turbulent_schmidt import turbulent_schmidt as turbulent_schmidt_cls

class user_defined(Group):
    """
    'user_defined' child.
    """

    fluent_name = "user-defined"

    child_names = \
        ['subgrid_scale_turb_visc', 'turb_visc_func_mf', 'turb_visc_func',
         'tke_prandtl', 'tdr_prandtl', 'sdr_prandtl', 'energy_prandtl',
         'wall_prandtl', 'turbulent_schmidt']

    _child_classes = dict(
        subgrid_scale_turb_visc=subgrid_scale_turb_visc_cls,
        turb_visc_func_mf=turb_visc_func_mf_cls,
        turb_visc_func=turb_visc_func_cls,
        tke_prandtl=tke_prandtl_cls,
        tdr_prandtl=tdr_prandtl_cls,
        sdr_prandtl=sdr_prandtl_cls,
        energy_prandtl=energy_prandtl_cls,
        wall_prandtl=wall_prandtl_cls,
        turbulent_schmidt=turbulent_schmidt_cls,
    )

    return_type = "<object object at 0x7fc5c18a5260>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .list import list as list_cls
from .list_properties import list_properties as list_properties_cls
from .duplicate_2 import duplicate as duplicate_cls
from .create_1 import create_1 as create_1_cls
from .load_case_data import load_case_data as load_case_data_cls
from .set_as_current_1 import set_as_current as set_as_current_cls
from .delete_design_points import delete_design_points as delete_design_points_cls
from .save_journals import save_journals as save_journals_cls
from .clear_generated_data import clear_generated_data as clear_generated_data_cls
from .update_current import update_current as update_current_cls
from .update_all import update_all as update_all_cls
from .update_selected import update_selected as update_selected_cls
from .design_points_child import design_points_child


class design_points(NamedObject[design_points_child], CreatableNamedObjectMixinOld[design_points_child]):
    """
    'design_points' child.
    """

    fluent_name = "design-points"

    command_names = \
        ['list', 'list_properties', 'duplicate', 'create_1', 'load_case_data',
         'set_as_current', 'delete_design_points', 'save_journals',
         'clear_generated_data', 'update_current', 'update_all',
         'update_selected']

    _child_classes = dict(
        list=list_cls,
        list_properties=list_properties_cls,
        duplicate=duplicate_cls,
        create_1=create_1_cls,
        load_case_data=load_case_data_cls,
        set_as_current=set_as_current_cls,
        delete_design_points=delete_design_points_cls,
        save_journals=save_journals_cls,
        clear_generated_data=clear_generated_data_cls,
        update_current=update_current_cls,
        update_all=update_all_cls,
        update_selected=update_selected_cls,
    )

    child_object_type: design_points_child = design_points_child
    """
    child_object_type of design_points.
    """
    return_type = "<object object at 0x7fb5f5f73aa0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .injection_names import injection_names as injection_names_cls

class particle_summary(Command):
    """
    Print summary report for all current particles.
    
    Parameters
    ----------
        injection_names : List
            'injection_names' child.
    
    """

    fluent_name = "particle-summary"

    argument_names = \
        ['injection_names']

    _child_classes = dict(
        injection_names=injection_names_cls,
    )

    return_type = "<object object at 0x7fb5f5f73560>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .model_tip_loss import model_tip_loss as model_tip_loss_cls
from .tip_loss_limit import tip_loss_limit as tip_loss_limit_cls
from .prandtl_tuning_coefficient import prandtl_tuning_coefficient as prandtl_tuning_coefficient_cls

class tip_loss(Group):
    fluent_name = ...
    child_names = ...
    model_tip_loss: model_tip_loss_cls = ...
    tip_loss_limit: tip_loss_limit_cls = ...
    prandtl_tuning_coefficient: prandtl_tuning_coefficient_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .band_width import band_width as band_width_cls
from .reorder_domain import reorder_domain as reorder_domain_cls
from .reorder_zones import reorder_zones as reorder_zones_cls

class reorder(Group):
    """
    Enter the reorder domain menu.
    """

    fluent_name = "reorder"

    command_names = \
        ['band_width', 'reorder_domain', 'reorder_zones']

    _child_classes = dict(
        band_width=band_width_cls,
        reorder_domain=reorder_domain_cls,
        reorder_zones=reorder_zones_cls,
    )

    return_type = "<object object at 0x7fc5c18a7a30>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .scalar_parameters import scalar_parameters as scalar_parameters_cls
from .coupled_parameters import coupled_parameters as coupled_parameters_cls
from .flexible_cycle_parameters import flexible_cycle_parameters as flexible_cycle_parameters_cls
from .options_2 import options as options_cls

class amg_controls(Group):
    fluent_name = ...
    child_names = ...
    scalar_parameters: scalar_parameters_cls = ...
    coupled_parameters: coupled_parameters_cls = ...
    flexible_cycle_parameters: flexible_cycle_parameters_cls = ...
    options: options_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .all import all as all_cls
from .auto import auto as auto_cls
from .use_local_edge_length_factor import use_local_edge_length_factor as use_local_edge_length_factor_cls
from .tolerance1 import tolerance1 as tolerance1_cls
from .tolerance2 import tolerance2 as tolerance2_cls

class convert_to_mapped_interface(Command):
    """
    Convert non-conformal mesh interface to mapped mesh interfaces.
    
    Parameters
    ----------
        all : bool
            Convert all mesh interfaces to mapped mesh interfaces.
        auto : bool
            Convert poorly matching mesh interfaces to mapped mesh interfaces.
        use_local_edge_length_factor : bool
            Enable tolerance based on local edge length factor instead of absolute tolerance.
        tolerance1 : real
            'tolerance1' child.
        tolerance2 : real
            'tolerance2' child.
    
    """

    fluent_name = "convert-to-mapped-interface"

    argument_names = \
        ['all', 'auto', 'use_local_edge_length_factor', 'tolerance1',
         'tolerance2']

    _child_classes = dict(
        all=all_cls,
        auto=auto_cls,
        use_local_edge_length_factor=use_local_edge_length_factor_cls,
        tolerance1=tolerance1_cls,
        tolerance2=tolerance2_cls,
    )

    return_type = "<object object at 0x7fb5f629a070>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .name import name as name_cls
from .scope import scope as scope_cls
from .cell_zones import cell_zones as cell_zones_cls
from .surfaces import surfaces as surfaces_cls
from .cell_centered import cell_centered as cell_centered_cls
from .format_class import format_class as format_class_cls
from .cgns_scalar import cgns_scalar as cgns_scalar_cls

class cgns(Command):
    fluent_name = ...
    argument_names = ...
    name: name_cls = ...
    scope: scope_cls = ...
    cell_zones: cell_zones_cls = ...
    surfaces: surfaces_cls = ...
    cell_centered: cell_centered_cls = ...
    format_class: format_class_cls = ...
    cgns_scalar: cgns_scalar_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .theory import theory as theory_cls
from .wave_ht import wave_ht as wave_ht_cls
from .wave_len import wave_len as wave_len_cls
from .phase_diff import phase_diff as phase_diff_cls
from .heading_angle import heading_angle as heading_angle_cls

class wave_list_child(Group):
    """
    'child_object_type' of wave_list.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['theory', 'wave_ht', 'wave_len', 'phase_diff', 'heading_angle']

    _child_classes = dict(
        theory=theory_cls,
        wave_ht=wave_ht_cls,
        wave_len=wave_len_cls,
        phase_diff=phase_diff_cls,
        heading_angle=heading_angle_cls,
    )

    return_type = "<object object at 0x7fc55461eba0>"
